@@ -18,4 +18,6 @@ from aerospike_helpers.expressions.base import *
 from aerospike_helpers.expressions.bitwise import *
 from aerospike_helpers.expressions.hll import *
 from aerospike_helpers.expressions.list import *
-from aerospike_helpers.expressions.map import *
\ No newline at end of file
+from aerospike_helpers.expressions.map import *
+from aerospike_helpers.expressions.arithmetic import *
+from aerospike_helpers.expressions.bitwise_operators import *
\ No newline at end of file
