@@ -15,7 +15,7 @@
 ##########################################################################
 '''
 Helper functions to create bit operation dictionary arguments for
-the :mod:`aerospike.Client.operate` and :mod:`aerospike.Client.operate_ordered` methods of the aerospike client.
+the :meth:`aerospike.operate` and :meth:`aerospike.operate_ordered` methods of the aerospike client.
 
     .. note:: Bitwise operations require server version >= 4.6.0
 
@@ -29,146 +29,109 @@ Offset examples:
 
 Example::
 
-    from __future__ import print_function
     import aerospike
-    from aerospike import exception as ex
     from aerospike_helpers.operations import bitwise_operations
-    import sys
 
     # Configure the client.
     config = {"hosts": [("127.0.0.1", 3000)]}
-
     # Create a client and connect it to the cluster.
-    try:
-        client = aerospike.client(config).connect()
-    except ex.ClientError as e:
-        print("Error: {0} [{1}]".format(e.msg, e.code))
-        sys.exit(1)
+    client = aerospike.client(config).connect()
 
     key = ("test", "demo", "foo")
     five_ones_bin_name = "bitwise1"
     five_one_blob = bytearray([1] * 5)
-
     # Write the record.
-    try:
-        client.put(key, {five_ones_bin_name: five_one_blob})
-    except ex.RecordError as e:
-        print("Error: {0} [{1}]".format(e.msg, e.code))
+    client.put(key, {five_ones_bin_name: five_one_blob})
 
     # EXAMPLE 1: resize the five_ones bin to a bytesize of 10.
-    try:
-        ops = [bitwise_operations.bit_resize(five_ones_bin_name, 10)]
 
-        _, _, bins = client.get(key)
-        _, _, _ = client.operate(key, ops)
-        _, _, newbins = client.get(key)
-        print("EXAMPLE 1: before resize: ", bins)
-        print("EXAMPLE 1: is now: ", newbins)
-    except ex.ClientError as e:
-        print("Error: {0} [{1}]".format(e.msg, e.code))
-        sys.exit(1)
+    ops = [bitwise_operations.bit_resize(five_ones_bin_name, 10)]
+
+    _, _, bins = client.get(key)
+    print("5 bytes: ", bins)
+    # 5 bytes:  {'bitwise1': b'\x01\x01\x01\x01\x01'}
+
+    _, _, _ = client.operate(key, ops)
+
+    _, _, newbins = client.get(key)
+    print("After resize to 10 bytes: ", newbins)
+    # After resize to 10 bytes:  {'bitwise1': b'\x01\x01\x01\x01\x01\x00\x00\x00\x00\x00'}
 
     # EXAMPLE 2: shrink the five_ones bin to a bytesize of 5 from the front.
-    try:
-        ops = [
-            bitwise_operations.bit_resize(
-                five_ones_bin_name, 5, resize_flags=aerospike.BIT_RESIZE_FROM_FRONT
-            )
-        ]
 
-        _, _, bins = client.get(key)
-        _, _, _ = client.operate(key, ops)
-        _, _, newbins = client.get(key)
-        print("EXAMPLE 2: before resize: ", bins)
-        print("EXAMPLE 2: is now: ", newbins)
-    except ex.ClientError as e:
-        print("Error: {0} [{1}]".format(e.msg, e.code))
-        sys.exit(1)
+    ops = [
+        bitwise_operations.bit_resize(
+            five_ones_bin_name, 5, resize_flags=aerospike.BIT_RESIZE_FROM_FRONT
+        )
+    ]
+
+    _, _, _ = client.operate(key, ops)
+    _, _, newbins = client.get(key)
+    print("After resize to 5 bytes again: ", newbins)
+    # After resize to 5 bytes again:  {'bitwise1': b'\x00\x00\x00\x00\x00'}
 
     # Cleanup and close the connection to the Aerospike cluster.
     client.remove(key)
     client.close()
 
-    """
-    EXPECTED OUTPUT:
-    EXAMPLE 1: before resize:  {'bitwise1': bytearray(b'\\x01\\x01\\x01\\x01\\x01')}
-    EXAMPLE 1: is now:  {'bitwise1': bytearray(b'\\x01\\x01\\x01\\x01\\x01\\x00\\x00\\x00\\x00\\x00')}
-    EXAMPLE 2: before resize:  {'bitwise1': bytearray(b'\\x01\\x01\\x01\\x01\\x01\\x00\\x00\\x00\\x00\\x00')}
-    EXAMPLE 2: is now:  {'bitwise1': bytearray(b'\\x00\\x00\\x00\\x00\\x00')}
-    """
-
 Example::
 
-    from __future__ import print_function
     import aerospike
     from aerospike import exception as e
     from aerospike_helpers.operations import bitwise_operations
 
     config = {'hosts': [('127.0.0.1', 3000)]}
-    try:
-        client = aerospike.client(config).connect()
-    except e.ClientError as e:
-        print("Error: {0} [{1}]".format(e.msg, e.code))
-        sys.exit(2)
+    client = aerospike.client(config).connect()
 
     key = ('test', 'demo', 'bit_example')
     five_one_blob = bytearray([1] * 5)
     five_one_bin = 'bitwise1'
 
-    try:
-        if client.exists(key):
-            client.remove(key)
-        bit_policy = {
-            'map_write_mode': aerospike.BIT_WRITE_DEFAULT,
-        }
-        client.put(
-            key,
-            {
-                five_one_bin: five_one_blob
-            }
-        )
+    # Precleanup
+    _, meta = client.exists(key)
+    if meta != None:
+        client.remove(key)
 
-        # Example 1: read bits
-        ops = [
-            bitwise_operations.bit_get(five_one_bin, 0, 40)
-        ]
-        print('=====EXAMPLE1=====')
-        _, _, results = client.operate(key, ops)
-        print(results)
+    bit_policy = {
+        'map_write_mode': aerospike.BIT_WRITE_DEFAULT,
+    }
+    client.put(key, {five_one_bin: five_one_blob})
 
-        # Example 2: modify bits using the 'or' op, then read bits
-        ops = [
-            bitwise_operations.bit_or(five_one_bin, 0, 8, 1, bytearray([255]), bit_policy),
-            bitwise_operations.bit_get(five_one_bin, 0, 40)
-        ]
-        print('=====EXAMPLE2=====')
-        _, _, results = client.operate(key, ops)
-        print(results)
+    # Example 1: read bits
+    ops = [
+        bitwise_operations.bit_get(five_one_bin, 0, 40)
+    ]
+    _, _, results = client.operate(key, ops)
+    print(results)
+    # {'bitwise1': b'\x01\x01\x01\x01\x01'}
 
-        # Example 3: modify bits using the 'remove' op, then read bits'
-        ops = [
-            bitwise_operations.bit_remove(five_one_bin, 0, 2, bit_policy),
-            bitwise_operations.bit_get(five_one_bin, 0, 24)
-        ]
-        print('=====EXAMPLE3=====')
-        _, _, results = client.operate(key, ops)
-        print(results)
+    # Example 2: modify bits using the 'or' op, then read bits
+    # 0 = offset
+    # 8 = num bits to OR
+    # value to OR: 0xff
+    # value size is 1 byte
+    ops = [
+        bitwise_operations.bit_or(five_one_bin, 0, 8, 1, bytearray([255]), bit_policy),
+        bitwise_operations.bit_get(five_one_bin, 0, 40)
+    ]
+    _, _, results = client.operate(key, ops)
+    print(results)
+    # {'bitwise1': b'\xff\x01\x01\x01\x01'}
 
-    except e.AerospikeError as e:
-        print("Error: {0} [{1}]".format(e.msg, e.code))
+    # Example 3: modify bits using the 'remove' op, then read bits'
+    # offset = 0
+    # # bytes to remove = 2
+    # Number of bits remaining = 24
+    ops = [
+        bitwise_operations.bit_remove(five_one_bin, 0, 2, bit_policy),
+        bitwise_operations.bit_get(five_one_bin, 0, 24)
+    ]
+    _, _, results = client.operate(key, ops)
+    print(results)
+    # {'bitwise1': b'\x01\x01\x01'}
 
     client.close()
 
-    """
-    EXPECTED OUTPUT:
-    =====EXAMPLE1=====
-    {'bitwise1': bytearray(b'\\x01\\x01\\x01\\x01\\x01')}
-    =====EXAMPLE2=====
-    {'bitwise1': bytearray(b'\\xff\\x01\\x01\\x01\\x01')}
-    =====EXAMPLE3=====
-    {'bitwise1': bytearray(b'\\x01\\x01\\x01')}
-    """
-
 .. seealso:: `Bits (Data Types) <https://www.aerospike.com/docs/guide/bitwise.html>`_.
 '''
 import aerospike
@@ -191,19 +154,16 @@ SIGN_KEY = "sign"
 ACTION_KEY = "action"
 
 
-def bit_resize(bin_name, byte_size, policy=None, resize_flags=aerospike.BIT_RESIZE_DEFAULT):
-    """Creates a bit_resize_operation to be used with operate or operate_ordered.
+def bit_resize(bin_name: str, byte_size, policy=None, resize_flags: int=0):
+    """Creates a bit_resize_operation to be used with :meth:`aerospike.operate` or :meth:`aerospike.operate_ordered`.
 
     Change the size of a bytes bin stored in a record on the Aerospike Server.
 
     Args:
         bin_name (str): The name of the bin containing the map.
         byte_size (int): The new size of the bytes.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
-        resize_flags (int, optional): Flags modifying the behavior of the resize.
-            This should be constructed by bitwise or'ing together any of the values: :ref:`aerospike_bitwise_resize_flag` . 
-            e.g. `aerospike.BIT_RESIZE_GROW_ONLY | aerospike.BIT_RESIZE_FROM_FRONT`
-            default: :data:`aerospike.BIT_RESIZE_DEFAULT`
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
+        resize_flags (int): :ref:`aerospike_bitwise_resize_flag` modifying the resize behavior (default ``aerospike.BIT_RESIZE_DEFAULT``), such as ``aerospike.BIT_RESIZE_GROW_ONLY | aerospike.BIT_RESIZE_FROM_FRONT``.
 
     Returns:
         A dictionary usable in operate or operate_ordered. The format of the dictionary
@@ -218,8 +178,8 @@ def bit_resize(bin_name, byte_size, policy=None, resize_flags=aerospike.BIT_RESI
     }
 
 
-def bit_remove(bin_name, byte_offset, byte_size, policy=None):
-    """Creates a bit_remove_operation to be used with operate or operate_ordered.
+def bit_remove(bin_name: str, byte_offset, byte_size, policy=None):
+    """Creates a bit_remove_operation to be used with :meth:`aerospike.operate` or :meth:`aerospike.operate_ordered`.
 
     Remove bytes from bitmap at byte_offset for byte_size.
 
@@ -227,7 +187,7 @@ def bit_remove(bin_name, byte_offset, byte_size, policy=None):
         bin_name (str): The name of the bin containing the map.
         byte_offset (int): Position of bytes to be removed.
         byte_size (int): How many bytes to remove.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
         A dictionary usable in operate or operate_ordered. The format of the dictionary
@@ -242,8 +202,8 @@ def bit_remove(bin_name, byte_offset, byte_size, policy=None):
     }
 
 
-def bit_set(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None):
-    """Creates a bit_set_operation to be used with operate or operate_ordered.
+def bit_set(bin_name: str, bit_offset, bit_size, value_byte_size, value, policy=None):
+    """Creates a bit_set_operation to be used with :meth:`aerospike.operate` or :meth:`aerospike.operate_ordered`.
 
     Set the value on a bitmap at bit_offset for bit_size in a record on the Aerospike Server.
 
@@ -252,8 +212,8 @@ def bit_set(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None)
         bit_offset (int): The offset where the bits will be set.
         bit_size (int): How many bits of value to write.
         value_byte_size (int): Size of value in bytes.
-        value (bytes/byte array): The value to be set.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        value (bytes, bytearray): The value to be set.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
         A dictionary usable in operate or operate_ordered. The format of the dictionary
@@ -270,8 +230,8 @@ def bit_set(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None)
     }
 
 
-def bit_count(bin_name, bit_offset, bit_size):
-    """Creates a bit_count_operation to be used with operate or operate_ordered.
+def bit_count(bin_name: str, bit_offset, bit_size):
+    """Creates a bit_count_operation to be used with :meth:`aerospike.operate` or :meth:`aerospike.operate_ordered`.
 
     Server returns an integer count of all set bits starting at bit_offset for bit_size bits.
 
@@ -292,8 +252,8 @@ def bit_count(bin_name, bit_offset, bit_size):
     }
 
 
-def bit_add(bin_name, bit_offset, bit_size, value, sign, action, policy=None):
-    """Creates a bit_add_operation to be used with operate or operate_ordered.
+def bit_add(bin_name: str, bit_offset, bit_size, value, sign, action, policy=None):
+    """Creates a bit_add_operation.
 
     Creates a bit add operation. Server adds value to the bin at bit_offset for bit_size.
     bit_size must <= 64. If Sign is true value will be treated as a signed number.
@@ -306,10 +266,10 @@ def bit_add(bin_name, bit_offset, bit_size, value, sign, action, policy=None):
         value (int): The value to be added.
         sign (bool): True: treat value as signed, False: treat value as unsigned.
         action (aerospike.constant): Action taken if an overflow/underflow occurs.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -324,8 +284,8 @@ def bit_add(bin_name, bit_offset, bit_size, value, sign, action, policy=None):
     }
 
 
-def bit_and(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None):
-    """Creates a bit_and_operation to be used with operate or operate_ordered.
+def bit_and(bin_name: str, bit_offset, bit_size, value_byte_size, value, policy=None):
+    """Creates a bit_and_operation.
 
     Creates a bit and operation. Server performs an and op with value and bitmap in bin
     at bit_offset for bit_size. Server returns nothing.
@@ -335,11 +295,11 @@ def bit_and(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None)
         bit_offset (int): The offset where the bits will be modified.
         bit_size (int): How many bits of value to and.
         value_byte_size (int): Length of value in bytes.
-        value (bytes/byte array): Bytes to be used in and operation.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        value (bytes, bytearray): Bytes to be used in and operation.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -353,8 +313,8 @@ def bit_and(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None)
     }
 
 
-def bit_get(bin_name, bit_offset, bit_size):
-    """Creates a bit_get_operation to be used with operate or operate_ordered.
+def bit_get(bin_name: str, bit_offset, bit_size):
+    """Creates a bit_get_operation.
 
     Server returns bits from bitmap starting at bit_offset for bit_size.
 
@@ -364,7 +324,7 @@ def bit_get(bin_name, bit_offset, bit_size):
         bit_size (int): How many bits to get.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -375,8 +335,8 @@ def bit_get(bin_name, bit_offset, bit_size):
     }
 
 
-def bit_get_int(bin_name, bit_offset, bit_size, sign):
-    """Creates a bit_get_int_operation to be used with operate or operate_ordered.
+def bit_get_int(bin_name: str, bit_offset, bit_size, sign):
+    """Creates a bit_get_int_operation.
 
     Server returns an integer formed from the bits read
     from bitmap starting at bit_offset for bit_size.
@@ -388,7 +348,7 @@ def bit_get_int(bin_name, bit_offset, bit_size, sign):
         sign (bool): True: Treat read value as signed. False: treat read value as unsigned.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -400,8 +360,8 @@ def bit_get_int(bin_name, bit_offset, bit_size, sign):
     }
 
 
-def bit_insert(bin_name, byte_offset, value_byte_size, value, policy=None):
-    """Creates a bit_insert_operation to be used with operate or operate_ordered.
+def bit_insert(bin_name: str, byte_offset, value_byte_size, value, policy=None):
+    """Creates a bit_insert_operation.
 
     Server inserts the bytes from value into the bitmap at byte_offset.
     No value is returned.
@@ -410,12 +370,12 @@ def bit_insert(bin_name, byte_offset, value_byte_size, value, policy=None):
         bin_name (str): The name of the bin containing the map.
         byte_offset (int): The offset where the bytes will be inserted.
         value_byte_size (int): Size of value in bytes.
-        value (bytes/byte array) The value to be inserted.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        value (bytes, bytearray): The value to be inserted.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -428,8 +388,8 @@ def bit_insert(bin_name, byte_offset, value_byte_size, value, policy=None):
     }
 
 
-def bit_lscan(bin_name, bit_offset, bit_size, value):
-    """Creates a bit_lscan_operation to be used with operate or operate_ordered.
+def bit_lscan(bin_name: str, bit_offset, bit_size, value):
+    """Creates a bit_lscan_operation.
 
     Server returns an integer representing the bit offset of the first occurence
     of the specified value bit. Starts scanning at bit_offset for bit_size. Returns
@@ -442,7 +402,7 @@ def bit_lscan(bin_name, bit_offset, bit_size, value):
         value (bool): True: look for 1, False: look for 0.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -454,8 +414,8 @@ def bit_lscan(bin_name, bit_offset, bit_size, value):
     }
 
 
-def bit_lshift(bin_name, bit_offset, bit_size, shift, policy=None):
-    """Creates a bit_lshift_operation to be used with operate or operate_ordered.
+def bit_lshift(bin_name: str, bit_offset, bit_size, shift, policy=None):
+    """Creates a bit_lshift_operation.
 
     Server left shifts bitmap starting at bit_offset for bit_size by shift bits.
     No value is returned.
@@ -465,10 +425,10 @@ def bit_lshift(bin_name, bit_offset, bit_size, shift, policy=None):
         bit_offset (int): The offset where the bits will start being shifted.
         bit_size (int): The number of bits that will be shifted by shift places.
         shift (int): How many bits to shift by.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -481,8 +441,8 @@ def bit_lshift(bin_name, bit_offset, bit_size, shift, policy=None):
     }
 
 
-def bit_not(bin_name, bit_offset, bit_size, policy=None):
-    """Creates a bit_not_operation to be used with operate or operate_ordered.
+def bit_not(bin_name: str, bit_offset, bit_size, policy=None):
+    """Creates a bit_not_operation.
 
     Server negates bitmap starting at bit_offset for bit_size.
     No value is returned.
@@ -491,10 +451,10 @@ def bit_not(bin_name, bit_offset, bit_size, policy=None):
         bin_name (str): The name of the bin containing the map.
         bit_offset (int): The offset where the bits will start being scanned.
         bit_size (int): How many bits to scan.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -506,11 +466,13 @@ def bit_not(bin_name, bit_offset, bit_size, policy=None):
     }
 
 
-def bit_or(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None):
-    """Creates a bit_or_operation to be used with operate or operate_ordered.
+def bit_or(bin_name: str, bit_offset, bit_size, value_byte_size, value, policy=None):
+    """Creates a bit_or_operation.
 
     Creates a bit or operation. Server performs bitwise or with value and bitmap in bin
-    at bit_offset for bit_size. Server returns nothing.
+    at bit_offset for bit_size.
+
+    Server returns nothing.
 
     Args:
         bin_name (str): The name of the bin containing the map.
@@ -518,10 +480,10 @@ def bit_or(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None):
         bit_size (int): How many bits of value to or.
         value_byte_size (int): Length of value in bytes.
         value (bytes/byte array): Value to be used in or operation.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -535,8 +497,8 @@ def bit_or(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None):
     }
 
 
-def bit_rscan(bin_name, bit_offset, bit_size, value):
-    """Creates a bit_rscan_operation to be used with operate or operate_ordered.
+def bit_rscan(bin_name: str, bit_offset, bit_size, value):
+    """Creates a bit_rscan_operation.
 
     Server returns an integer representing the bit offset of the last occurence
     of the specified value bit. Starts scanning at bit_offset for bit_size. Returns
@@ -549,7 +511,7 @@ def bit_rscan(bin_name, bit_offset, bit_size, value):
         value (bool): True: Look for 1, False: look for 0.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -561,8 +523,8 @@ def bit_rscan(bin_name, bit_offset, bit_size, value):
     }
 
 
-def bit_rshift(bin_name, bit_offset, bit_size, shift, policy=None):
-    """Creates a bit_rshift_operation to be used with operate or operate_ordered.
+def bit_rshift(bin_name: str, bit_offset, bit_size, shift, policy=None):
+    """Creates a bit_rshift_operation.
 
     Server right shifts bitmap starting at bit_offset for bit_size by shift bits.
     No value is returned.
@@ -572,10 +534,10 @@ def bit_rshift(bin_name, bit_offset, bit_size, shift, policy=None):
         bit_offset (int): The offset where the bits will start being shifted.
         bit_size (int): The number of bits that will be shifted by shift places.
         shift (int): How many bits to shift by.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -588,12 +550,14 @@ def bit_rshift(bin_name, bit_offset, bit_size, shift, policy=None):
     }
 
 
-def bit_subtract(bin_name, bit_offset, bit_size, value, sign, action, policy=None):
-    """Creates a bit_subtract_operation to be used with operate or operate_ordered.
+def bit_subtract(bin_name: str, bit_offset, bit_size, value, sign, action, policy=None):
+    """Creates a bit_subtract_operation.
 
-    Creates a bit add operation. Server subtracts value from the bits at bit_offset for bit_size.
+    Server subtracts value from the bits at bit_offset for bit_size.
     bit_size must <= 64. If sign is true value will be treated as a signed number.
-    If an underflow or overflow occurs, as_bit_overflow_action is used. Server returns nothing.
+    If an underflow or overflow occurs, as_bit_overflow_action is used.
+
+    Server returns nothing.
 
     Args:
         bin_name (str): The name of the bin containing the map.
@@ -602,10 +566,10 @@ def bit_subtract(bin_name, bit_offset, bit_size, value, sign, action, policy=Non
         value (int): The value to be subtracted.
         sign (bool): True: treat value as signed, False: treat value as unsigned.
         action (aerospike.constant): Action taken if an overflow/underflow occurs.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -620,8 +584,8 @@ def bit_subtract(bin_name, bit_offset, bit_size, value, sign, action, policy=Non
     }
 
 
-def bit_xor(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None):
-    """Creates a bit_xor_operation to be used with operate or operate_ordered.
+def bit_xor(bin_name: str, bit_offset, bit_size, value_byte_size, value, policy=None):
+    """Creates a bit_xor_operation.
 
     Creates a bit and operation. Server performs bitwise xor with value and bitmap in bin
     at bit_offset for bit_size. Server returns nothing.
@@ -632,10 +596,10 @@ def bit_xor(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None)
         bit_size (int): How many bits of value to xor.
         value_byte_size (int): Length of value in bytes.
         value (bytes/byte array): Value to be used in xor operation.
-        policy (dict, optional): The :ref:`bit_policy policy <aerospike_bit_policies>` dictionary. default: None.
+        policy (dict): The :ref:`bit_policy <aerospike_bit_policies>` dictionary. default: None.
 
     Returns:
-        A dictionary usable in operate or operate_ordered. The format of the dictionary
+        A dictionary usable in :meth:`~aerospike.Client.operate` or :meth:`~aerospike.Client.operate_ordered`. The format of the dictionary
         should be considered an internal detail, and subject to change.
     """
     return {
@@ -646,4 +610,4 @@ def bit_xor(bin_name, bit_offset, bit_size, value_byte_size, value, policy=None)
         BIT_SIZE_KEY: bit_size,
         VALUE_BYTE_SIZE_KEY: value_byte_size,
         VALUE_KEY: value
-    }
\ No newline at end of file
+    }
