@@ -22,5 +22,8 @@
 #include "types.h"
 #include <aerospike/as_operations.h>
 
-as_status add_new_bit_op(AerospikeClient* self, as_error* err, PyObject* op_dict, as_vector* unicodeStrVector,
-    as_static_pool* static_pool, as_operations* ops, long operation_code, long* ret_type, int serializer_type);
+as_status add_new_bit_op(AerospikeClient *self, as_error *err,
+						 PyObject *op_dict, as_vector *unicodeStrVector,
+						 as_static_pool *static_pool, as_operations *ops,
+						 long operation_code, long *ret_type,
+						 int serializer_type);
