@@ -22,7 +22,7 @@
 #define RECORD_EXCEPTION_COUNT 10
 #define SERVER_EXCEPTION_COUNT 13
 #define INDEX_EXCEPTION_COUNT 6
-#define ADMIN_EXCEPTION_COUNT 17
+#define ADMIN_EXCEPTION_COUNT 22
 
 struct exceptions {
 	PyObject *AerospikeError;
@@ -41,27 +41,30 @@ struct exceptions {
 	PyObject *ForbiddenError;
 	PyObject *QueryError;
 	PyObject *InvalidGeoJSON;
-	PyObject *OpNotApplicable; //26
-	PyObject *FilteredOut; //27
-	PyObject *LostConflict; //28
-	PyObject *ScanAbortedError; //15
+	PyObject *OpNotApplicable;		//26
+	PyObject *FilteredOut;			//27
+	PyObject *LostConflict;			//28
+	PyObject *ScanAbortedError;		//15
 	PyObject *ElementNotFoundError; //23
-	PyObject *ElementExistsError; //24
-	PyObject *BatchDisabledError; //150
+	PyObject *ElementExistsError;	//24
+	PyObject *BatchDisabledError;	//150
 	PyObject *BatchMaxRequestError; //151
-	PyObject *BatchQueueFullError; //152
-	PyObject *QueryAbortedError; //210
+	PyObject *BatchQueueFullError;	//152
+	PyObject *QueryAbortedError;	//210
 
 	//Client exceptions
 	PyObject *ParamError;
 	PyObject *InvalidHostError;
 	PyObject *NamespaceNotFound;
 	PyObject *ConnectionError;
-	PyObject *TLSError; //-9
-	PyObject *InvalidNodeError; //-8
+	PyObject *BatchFailed;			  //-16
+	PyObject *NoResponse;			  //-15
+	PyObject *MaxRetriesExceeded;	  //-12
+	PyObject *TLSError;				  //-9
+	PyObject *InvalidNodeError;		  //-8
 	PyObject *NoMoreConnectionsError; // -7
-	PyObject *AsyncConnectionError; // -6
-	PyObject *ClientAbortError; // -5
+	PyObject *AsyncConnectionError;	  // -6
+	PyObject *ClientAbortError;		  // -5
 
 	//Record exceptions
 	PyObject *RecordError;
@@ -104,6 +107,11 @@ struct exceptions {
 	PyObject *RoleViolation;
 	PyObject *InvalidPrivilege;
 	PyObject *NotAuthenticated;
+	PyObject *InvalidWhitelist;
+	PyObject *NotWhitelisted;
+	PyObject *QuotasNotEnabled;
+	PyObject *InvalidQuota;
+	PyObject *QuotaExceeded;
 
 	//UDF exceptions
 	PyObject *UDFError;
@@ -117,29 +125,27 @@ struct exceptions {
 	//Query exceptions
 	PyObject *QueryQueueFull;
 	PyObject *QueryTimeout;
-
 };
 
 struct server_exceptions_struct {
-	PyObject** server_exceptions[SERVER_EXCEPTION_COUNT];
-	char* server_exceptions_name[SERVER_EXCEPTION_COUNT];
+	PyObject **server_exceptions[SERVER_EXCEPTION_COUNT];
+	char *server_exceptions_name[SERVER_EXCEPTION_COUNT];
 	int server_exceptions_codes[SERVER_EXCEPTION_COUNT];
 };
 struct record_exceptions_struct {
-	PyObject** record_exceptions[RECORD_EXCEPTION_COUNT];
-	char * record_exceptions_name[RECORD_EXCEPTION_COUNT];
+	PyObject **record_exceptions[RECORD_EXCEPTION_COUNT];
+	char *record_exceptions_name[RECORD_EXCEPTION_COUNT];
 	int record_exceptions_codes[RECORD_EXCEPTION_COUNT];
 };
 
 struct index_exceptions_struct {
-	PyObject** index_exceptions[INDEX_EXCEPTION_COUNT];
-	char* index_exceptions_name[INDEX_EXCEPTION_COUNT];
+	PyObject **index_exceptions[INDEX_EXCEPTION_COUNT];
+	char *index_exceptions_name[INDEX_EXCEPTION_COUNT];
 	int index_exceptions_codes[INDEX_EXCEPTION_COUNT];
 };
 
 struct admin_exceptions_struct {
-	PyObject** admin_exceptions[ADMIN_EXCEPTION_COUNT];
-	char* admin_exceptions_name[ADMIN_EXCEPTION_COUNT];
+	PyObject **admin_exceptions[ADMIN_EXCEPTION_COUNT];
+	char *admin_exceptions_name[ADMIN_EXCEPTION_COUNT];
 	int admin_exceptions_codes[ADMIN_EXCEPTION_COUNT];
 };
-
