@@ -28,9 +28,10 @@
  * FUNCTIONS
  ******************************************************************************/
 
-PyTypeObject * AerospikeQuery_Ready(void);
+PyTypeObject *AerospikeQuery_Ready(void);
 
-AerospikeQuery * AerospikeQuery_New(AerospikeClient * client, PyObject * args, PyObject * kwds);
+AerospikeQuery *AerospikeQuery_New(AerospikeClient *client, PyObject *args,
+								   PyObject *kwds);
 
 /*******************************************************************************
  * OPERATIONS
@@ -48,13 +49,15 @@ AerospikeQuery * AerospikeQuery_New(AerospikeClient * client, PyObject * args, P
  *		query.select(bin, bin, bin)
  *
  */
-AerospikeQuery * AerospikeQuery_Select(AerospikeQuery * self, PyObject * args, PyObject * kwds);
+AerospikeQuery *AerospikeQuery_Select(AerospikeQuery *self, PyObject *args,
+									  PyObject *kwds);
 
 /**
  * Add a list of write operations to the query.
  *
  */
-AerospikeQuery * AerospikeQuery_Add_Ops(AerospikeQuery * self, PyObject * args, PyObject * kwds);
+AerospikeQuery *AerospikeQuery_Add_Ops(AerospikeQuery *self, PyObject *args,
+									   PyObject *kwds);
 
 /**
  * Add a where predicate to the query.
@@ -68,15 +71,7 @@ AerospikeQuery * AerospikeQuery_Add_Ops(AerospikeQuery * self, PyObject * args,
  *		query.select(bin, bin, bin)
  *
  */
-AerospikeQuery * AerospikeQuery_Where(AerospikeQuery * self, PyObject * args);
-
-/**
- * Apply a list of predicates to the query.
- *
- *		query.predexp(predexps)
- *
- */
-AerospikeQuery * AerospikeQuery_Predexp(AerospikeQuery * self, PyObject * args);
+AerospikeQuery *AerospikeQuery_Where(AerospikeQuery *self, PyObject *args);
 
 /**
  * Apply the specified udf on the results of the query.
@@ -84,7 +79,8 @@ AerospikeQuery * AerospikeQuery_Predexp(AerospikeQuery * self, PyObject * args);
  *		query.apply(module, function, arglist)
  *
  */
-AerospikeQuery * AerospikeQuery_Apply(AerospikeQuery * self, PyObject * args, PyObject * kwds);
+AerospikeQuery *AerospikeQuery_Apply(AerospikeQuery *self, PyObject *args,
+									 PyObject *kwds);
 
 /**
  * Execute the query and call the callback for each result returned.
@@ -95,7 +91,8 @@ AerospikeQuery * AerospikeQuery_Apply(AerospikeQuery * self, PyObject * args, Py
  *		query.foreach(each_result)
  *
  */
-PyObject * AerospikeQuery_Foreach(AerospikeQuery * self, PyObject * args, PyObject * kwds);
+PyObject *AerospikeQuery_Foreach(AerospikeQuery *self, PyObject *args,
+								 PyObject *kwds);
 
 /**
  * Execute the query and return a generator.
@@ -104,13 +101,40 @@ PyObject * AerospikeQuery_Foreach(AerospikeQuery * self, PyObject * args, PyObje
  *			print result
  *
  */
-PyObject * AerospikeQuery_Results(AerospikeQuery * self, PyObject * args, PyObject * kwds);
+PyObject *AerospikeQuery_Results(AerospikeQuery *self, PyObject *args,
+								 PyObject *kwds);
 
 /**
  * Execute a UDF in the background. Returns the query id to allow status of the query to be monitored.
  * */
 
-PyObject * AerospikeQuery_ExecuteBackground(AerospikeQuery * self, PyObject * args, PyObject * kwds);
+PyObject *AerospikeQuery_ExecuteBackground(AerospikeQuery *self, PyObject *args,
+										   PyObject *kwds);
+
+/**
+ * Set pagination filter to receive records in bunch (max_records or page_size).
+ *
+ *    query.paginate()
+ *
+ */
+PyObject *AerospikeQuery_Paginate(AerospikeQuery *self);
+
+/**
+ * Gets the status of the query.
+ *
+ *    If using query pagination, did the previous paginated query with this query instance
+ *    return all records?
+ *
+ */
+PyObject *AerospikeQuery_Is_Done(AerospikeQuery *self);
+
+/**
+ * Gets the complete partition status of the query.
+ *
+ *    Returns a dictionary of the form {id:(id, init, done, digest), ...}.
+ *
+ */
+PyObject *AerospikeQuery_Get_Partitions_status(AerospikeQuery *self);
 
 /**
  * Store the Unicode -> UTF8 string converted PyObject into 
@@ -119,11 +143,6 @@ PyObject * AerospikeQuery_ExecuteBackground(AerospikeQuery * self, PyObject * ar
  *		StoreUnicodePyObject(self, PyUnicode_AsUTF8String(py_bin));
  *
  */
-PyObject * StoreUnicodePyObject(AerospikeQuery * self, PyObject * obj);
+PyObject *StoreUnicodePyObject(AerospikeQuery *self, PyObject *obj);
 
-int64_t pyobject_to_int64(PyObject * py_obj);
-
-/* Initialize the predexp module */
-PyObject * AerospikePredExp_New(void);
-
-as_status RegisterPredExpConstants(PyObject* module);
\ No newline at end of file
+int64_t pyobject_to_int64(PyObject *py_obj);
\ No newline at end of file
