@@ -33,6 +33,7 @@
 extern int counter;
 extern PyObject *py_global_hosts;
 extern bool user_shm_key;
+extern uint32_t async_support;
 
 typedef struct {
 	PyObject_HEAD
@@ -47,16 +48,15 @@ typedef struct {
 } AerospikeCDTInfObject;
 
 typedef struct {
-	PyObject_HEAD
-	aerospike * as;
+	PyObject_HEAD aerospike *as;
 	int shm_key;
 	int ref_cnt;
 } AerospikeGlobalHosts;
 
 typedef struct {
 	as_error error;
-	PyObject * callback;
-}user_serializer_callback;
+	PyObject *callback;
+} user_serializer_callback;
 
 typedef struct {
 	PyObject *ob[MAX_UNICODE_OBJECTS];
@@ -64,8 +64,7 @@ typedef struct {
 } UnicodePyObjects;
 
 typedef struct {
-	PyObject_HEAD
-	aerospike * as;
+	PyObject_HEAD aerospike *as;
 	int is_conn_16;
 	user_serializer_callback user_serializer_call_info;
 	user_serializer_callback user_deserializer_call_info;
@@ -73,26 +72,28 @@ typedef struct {
 	uint8_t strict_types;
 	bool has_connected;
 	bool use_shared_connection;
+	uint8_t send_bool_as;
 } AerospikeClient;
 
 typedef struct {
-	PyObject_HEAD
-	AerospikeClient * client;
+	PyObject_HEAD AerospikeClient *client;
 	as_query query;
 	UnicodePyObjects u_objs;
-	as_vector * unicodeStrVector;
-	as_static_pool * static_pool;
+	as_vector *unicodeStrVector;
+	as_static_pool *static_pool;
 } AerospikeQuery;
 
 typedef struct {
-	PyObject_HEAD
-	AerospikeClient * client;
+	PyObject_HEAD AerospikeClient *client;
 	as_scan scan;
-	as_vector * unicodeStrVector;
-	as_static_pool * static_pool;
+	as_vector *unicodeStrVector;
+	as_static_pool *static_pool;
 } AerospikeScan;
 
 typedef struct {
-	PyObject_HEAD
-	PyObject *geo_data;
+	PyObject_HEAD PyObject *geo_data;
 } AerospikeGeospatial;
+
+typedef struct {
+	PyDictObject dict;
+} AerospikeKeyOrderedDict;
\ No newline at end of file
