@@ -36,100 +36,106 @@
 #include <aerospike/as_geojson.h>
 #include <aerospike/as_nil.h>
 
-#define BASE_VARIABLES\
-	as_error err;\
-	as_error_init(&err);\
-	PyObject * py_key = NULL;\
-	PyObject * py_bin = NULL;\
-	PyObject * py_policy = NULL;\
-	PyObject * py_meta = NULL;\
-	as_policy_operate operate_policy;\
-	as_policy_operate *operate_policy_p = NULL;\
-	as_key key;\
-	bool key_created = false;\
-	char* bin = NULL;\
+#define BASE_VARIABLES                                                         \
+	as_error err;                                                              \
+	as_error_init(&err);                                                       \
+	PyObject *py_key = NULL;                                                   \
+	PyObject *py_bin = NULL;                                                   \
+	PyObject *py_policy = NULL;                                                \
+	PyObject *py_meta = NULL;                                                  \
+	as_policy_operate operate_policy;                                          \
+	as_policy_operate *operate_policy_p = NULL;                                \
+	as_key key;                                                                \
+	bool key_created = false;                                                  \
+	char *bin = NULL;
 
-#define CHECK_CONNECTED_AND_CDT_SUPPORT()\
-	if (!self || !self->as) {\
-		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Invalid aerospike object");\
-		goto CLEANUP;\
-	}\
-	if (!self->is_conn_16) {\
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster");\
-		goto CLEANUP;\
-	}\
-	if (!has_cdt_list(self->as, &err)) {\
-		as_error_update(&err, AEROSPIKE_ERR_UNSUPPORTED_FEATURE, "CDT list feature is not supported");\
-		goto CLEANUP;\
-	}\
-
-#define POLICY_KEY_META_BIN()\
-	if (py_policy) {\
-		if (pyobject_to_policy_operate(self, &err, py_policy, &operate_policy, &operate_policy_p,\
-				&self->as->config.policies.operate, NULL, NULL, NULL, NULL) != AEROSPIKE_OK) {\
-			goto CLEANUP;\
-		}\
-	}\
-	if (pyobject_to_key(&err, py_key, &key) != AEROSPIKE_OK) {\
-		goto CLEANUP;\
-	} else {\
-		key_created = true;\
-	}\
-	if (py_meta) {\
-		if (check_for_meta(py_meta, &ops, &err) != AEROSPIKE_OK) {\
-			goto CLEANUP;\
-		}\
-	}\
-	if (bin_strict_type_checking(self, &err, py_bin, &bin) != AEROSPIKE_OK) {\
-		goto CLEANUP;\
-	}\
-
-#define DO_OPERATION(__rec)\
-	Py_BEGIN_ALLOW_THREADS\
-	aerospike_key_operate(self->as, &err, operate_policy_p, &key, &ops, __rec);\
-	Py_END_ALLOW_THREADS
-
-#define EXCEPTION_ON_ERROR()\
-	if (key_created) {\
-		as_key_destroy(&key);\
-	}\
-	if (err.code != AEROSPIKE_OK) {\
-		PyObject * py_err = NULL;\
-		error_to_pyobject(&err, &py_err);\
-		PyObject *exception_type = raise_exception(&err);\
-		if (PyObject_HasAttrString(exception_type, "key")) {\
-			PyObject_SetAttrString(exception_type, "key", py_key);\
-		}\
-		if (PyObject_HasAttrString(exception_type, "bin")) {\
-			PyObject_SetAttrString(exception_type, "bin", py_bin);\
-		}\
-		PyErr_SetObject(exception_type, py_err);\
-		Py_DECREF(py_err);\
-		return NULL;\
+#define CHECK_CONNECTED_AND_CDT_SUPPORT()                                      \
+	if (!self || !self->as) {                                                  \
+		as_error_update(&err, AEROSPIKE_ERR_PARAM,                             \
+						"Invalid aerospike object");                           \
+		goto CLEANUP;                                                          \
+	}                                                                          \
+	if (!self->is_conn_16) {                                                   \
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,                           \
+						"No connection to aerospike cluster");                 \
+		goto CLEANUP;                                                          \
+	}                                                                          \
+	if (!has_cdt_list(self->as, &err)) {                                       \
+		as_error_update(&err, AEROSPIKE_ERR_UNSUPPORTED_FEATURE,               \
+						"CDT list feature is not supported");                  \
+		goto CLEANUP;                                                          \
 	}
 
- /**
+#define POLICY_KEY_META_BIN()                                                  \
+	if (py_policy) {                                                           \
+		if (pyobject_to_policy_operate(self, &err, py_policy, &operate_policy, \
+									   &operate_policy_p,                      \
+									   &self->as->config.policies.operate,     \
+									   NULL, NULL) != AEROSPIKE_OK) {          \
+			goto CLEANUP;                                                      \
+		}                                                                      \
+	}                                                                          \
+	if (pyobject_to_key(&err, py_key, &key) != AEROSPIKE_OK) {                 \
+		goto CLEANUP;                                                          \
+	}                                                                          \
+	else {                                                                     \
+		key_created = true;                                                    \
+	}                                                                          \
+	if (py_meta) {                                                             \
+		if (check_for_meta(py_meta, &ops, &err) != AEROSPIKE_OK) {             \
+			goto CLEANUP;                                                      \
+		}                                                                      \
+	}                                                                          \
+	if (bin_strict_type_checking(self, &err, py_bin, &bin) != AEROSPIKE_OK) {  \
+		goto CLEANUP;                                                          \
+	}
+
+#define DO_OPERATION(__rec)                                                    \
+	Py_BEGIN_ALLOW_THREADS                                                     \
+	aerospike_key_operate(self->as, &err, operate_policy_p, &key, &ops,        \
+						  __rec);                                              \
+	Py_END_ALLOW_THREADS
+
+#define EXCEPTION_ON_ERROR()                                                   \
+	if (key_created) {                                                         \
+		as_key_destroy(&key);                                                  \
+	}                                                                          \
+	if (err.code != AEROSPIKE_OK) {                                            \
+		PyObject *py_err = NULL;                                               \
+		error_to_pyobject(&err, &py_err);                                      \
+		PyObject *exception_type = raise_exception(&err);                      \
+		if (PyObject_HasAttrString(exception_type, "key")) {                   \
+			PyObject_SetAttrString(exception_type, "key", py_key);             \
+		}                                                                      \
+		if (PyObject_HasAttrString(exception_type, "bin")) {                   \
+			PyObject_SetAttrString(exception_type, "bin", py_bin);             \
+		}                                                                      \
+		PyErr_SetObject(exception_type, py_err);                               \
+		Py_DECREF(py_err);                                                     \
+		return NULL;                                                           \
+	}
+
+/**
   *******************************************************************************************************
   * Check whether Aerospike server supports CDT feature or not.
   *******************************************************************************************************
   */
- #define INFO_CALL "features"
- static bool has_cdt_list(aerospike *as, as_error *err)
- {
- 	char *res = NULL;
+#define INFO_CALL "features"
+static bool has_cdt_list(aerospike *as, as_error *err)
+{
+	char *res = NULL;
 
- 	int rc = aerospike_info_any(as, err, NULL, INFO_CALL, &res);
-
- 	if (rc == AEROSPIKE_OK) {
- 		char *st = strstr(res, "cdt-list");
- 		free(res);
- 		if (st) {
- 			return true;
- 		}
- 	}
- 	return false;
- }
+	int rc = aerospike_info_any(as, err, NULL, INFO_CALL, &res);
 
+	if (rc == AEROSPIKE_OK) {
+		char *st = strstr(res, "cdt-list");
+		free(res);
+		if (st) {
+			return true;
+		}
+	}
+	return false;
+}
 
 /**
  *******************************************************************************************************
@@ -144,18 +150,20 @@
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListAppend(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListAppend(AerospikeClient *self, PyObject *args,
+									 PyObject *kwds)
 {
 	BASE_VARIABLES
 
-	PyObject * py_append_val = NULL;
+	PyObject *py_append_val = NULL;
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "val", "meta", "policy", NULL};
+	static char *kwlist[] = {"key", "bin", "val", "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOO|OO:list_append", kwlist,
-				&py_key, &py_bin, &py_append_val, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &py_append_val, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -166,9 +174,9 @@ PyObject * AerospikeClient_ListAppend(AerospikeClient * self, PyObject * args, P
 
 	POLICY_KEY_META_BIN();
 
-	as_val* put_val = NULL;
-	if (pyobject_to_astype_write(self, &err, py_append_val, &put_val,
-			&static_pool, SERIALIZER_PYTHON) != AEROSPIKE_OK) {
+	as_val *put_val = NULL;
+	if (pyobject_to_val(self, &err, py_append_val, &put_val, &static_pool,
+						SERIALIZER_PYTHON) != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
 	as_operations_add_list_append(&ops, bin, put_val);
@@ -195,18 +203,20 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListExtend(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListExtend(AerospikeClient *self, PyObject *args,
+									 PyObject *kwds)
 {
 	BASE_VARIABLES
 
-	PyObject * py_append_val = NULL;
+	PyObject *py_append_val = NULL;
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "items", "meta", "policy", NULL};
+	static char *kwlist[] = {"key", "bin", "items", "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOO|OO:list_extend", kwlist,
-				&py_key, &py_bin, &py_append_val, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &py_append_val, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -216,19 +226,20 @@ PyObject * AerospikeClient_ListExtend(AerospikeClient * self, PyObject * args, P
 	memset(&static_pool, 0, sizeof(static_pool));
 
 	if (!PyList_Check(py_append_val)) {
-		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Items should be of type list");
+		as_error_update(&err, AEROSPIKE_ERR_PARAM,
+						"Items should be of type list");
 		goto CLEANUP;
 	}
 
 	POLICY_KEY_META_BIN();
 
-	as_val* put_val = NULL;
-	pyobject_to_astype_write(self, &err, py_append_val, &put_val,
-			&static_pool, SERIALIZER_PYTHON);
+	as_val *put_val = NULL;
+	pyobject_to_val(self, &err, py_append_val, &put_val, &static_pool,
+					SERIALIZER_PYTHON);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
-	as_operations_add_list_append_items(&ops, bin, (as_list*) put_val);
+	as_operations_add_list_append_items(&ops, bin, (as_list *)put_val);
 
 	DO_OPERATION(NULL);
 
@@ -252,18 +263,21 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListInsert(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListInsert(AerospikeClient *self, PyObject *args,
+									 PyObject *kwds)
 {
 	BASE_VARIABLES
 
-	PyObject * py_insert_val = NULL;
+	PyObject *py_insert_val = NULL;
 	uint64_t index;
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "val", "meta", "policy", NULL};
+	static char *kwlist[] = {"key",	 "bin",	   "index", "val",
+							 "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOlO|OO:list_insert", kwlist,
-				&py_key, &py_bin, &index, &py_insert_val, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &index, &py_insert_val,
+									&py_meta, &py_policy) == false) {
 		return NULL;
 	}
 
@@ -274,9 +288,9 @@ PyObject * AerospikeClient_ListInsert(AerospikeClient * self, PyObject * args, P
 
 	POLICY_KEY_META_BIN();
 
-	as_val* put_val = NULL;
-	pyobject_to_astype_write(self, &err, py_insert_val, &put_val,
-			&static_pool, SERIALIZER_PYTHON);
+	as_val *put_val = NULL;
+	pyobject_to_val(self, &err, py_insert_val, &put_val, &static_pool,
+					SERIALIZER_PYTHON);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
@@ -305,18 +319,21 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListInsertItems(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListInsertItems(AerospikeClient *self, PyObject *args,
+										  PyObject *kwds)
 {
 	BASE_VARIABLES
 
-	PyObject * py_insert_val = NULL;
+	PyObject *py_insert_val = NULL;
 	uint64_t index;
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "items", "meta", "policy", NULL};
-	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOlO|OO:list_insert_items", kwlist,
-				&py_key, &py_bin, &index, &py_insert_val, &py_meta, &py_policy) == false) {
+	static char *kwlist[] = {"key",	 "bin",	   "index", "items",
+							 "meta", "policy", NULL};
+	if (PyArg_ParseTupleAndKeywords(
+			args, kwds, "OOlO|OO:list_insert_items", kwlist, &py_key, &py_bin,
+			&index, &py_insert_val, &py_meta, &py_policy) == false) {
 		return NULL;
 	}
 
@@ -326,20 +343,21 @@ PyObject * AerospikeClient_ListInsertItems(AerospikeClient * self, PyObject * ar
 	memset(&static_pool, 0, sizeof(static_pool));
 
 	if (!PyList_Check(py_insert_val)) {
-		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Items should be of type list");
+		as_error_update(&err, AEROSPIKE_ERR_PARAM,
+						"Items should be of type list");
 		goto CLEANUP;
 	}
 
 	POLICY_KEY_META_BIN();
 
-	as_val* put_val = NULL;
-	pyobject_to_astype_write(self, &err, py_insert_val, &put_val,
-			&static_pool, SERIALIZER_PYTHON);
+	as_val *put_val = NULL;
+	pyobject_to_val(self, &err, py_insert_val, &put_val, &static_pool,
+					SERIALIZER_PYTHON);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
 
-	as_operations_add_list_insert_items(&ops, bin, index, (as_list*) put_val);
+	as_operations_add_list_insert_items(&ops, bin, index, (as_list *)put_val);
 
 	DO_OPERATION(NULL);
 
@@ -363,7 +381,8 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListSize(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListSize(AerospikeClient *self, PyObject *args,
+								   PyObject *kwds)
 {
 	BASE_VARIABLES
 
@@ -373,9 +392,10 @@ PyObject * AerospikeClient_ListSize(AerospikeClient * self, PyObject * args, PyO
 	as_operations_inita(&ops, 1);
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "meta", "policy", NULL};
+	static char *kwlist[] = {"key", "bin", "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OO|OO:list_size", kwlist,
-				&py_key, &py_bin, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -421,7 +441,8 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListPop(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListPop(AerospikeClient *self, PyObject *args,
+								  PyObject *kwds)
 {
 	BASE_VARIABLES
 
@@ -430,9 +451,10 @@ PyObject * AerospikeClient_ListPop(AerospikeClient * self, PyObject * args, PyOb
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "meta", "policy", NULL};
+	static char *kwlist[] = {"key", "bin", "index", "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOl|OO:list_pop", kwlist,
-				&py_key, &py_bin, &index, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &index, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -449,8 +471,10 @@ PyObject * AerospikeClient_ListPop(AerospikeClient * self, PyObject * args, PyOb
 	}
 	PyObject *py_val = NULL;
 	if (rec && rec->bins.size) {
-		val_to_pyobject(self, &err, (as_val*) (rec->bins.entries[0].valuep), &py_val);
-	} else {
+		val_to_pyobject(self, &err, (as_val *)(rec->bins.entries[0].valuep),
+						&py_val);
+	}
+	else {
 		py_val = Py_None;
 		Py_INCREF(py_val);
 	}
@@ -478,20 +502,23 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListPopRange(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListPopRange(AerospikeClient *self, PyObject *args,
+									   PyObject *kwds)
 {
 	BASE_VARIABLES
 
-	PyObject * py_list = NULL;
+	PyObject *py_list = NULL;
 	uint64_t index;
 	uint64_t count = -1;
 	as_record *rec = NULL;
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "count", "meta", "policy", NULL};
-	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOll|OO:list_pop_range", kwlist,
-				&py_key, &py_bin, &index, &count, &py_meta, &py_policy) == false) {
+	static char *kwlist[] = {"key",	 "bin",	   "index", "count",
+							 "meta", "policy", NULL};
+	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOll|OO:list_pop_range",
+									kwlist, &py_key, &py_bin, &index, &count,
+									&py_meta, &py_policy) == false) {
 		return NULL;
 	}
 
@@ -513,7 +540,8 @@ PyObject * AerospikeClient_ListPopRange(AerospikeClient * self, PyObject * args,
 	}
 	if (rec && rec->bins.size) {
 		list_to_pyobject(self, &err, as_record_get_list(rec, bin), &py_list);
-	} else {
+	}
+	else {
 		py_list = Py_None;
 		Py_INCREF(py_list);
 	}
@@ -541,7 +569,8 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListRemove(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListRemove(AerospikeClient *self, PyObject *args,
+									 PyObject *kwds)
 {
 	BASE_VARIABLES
 
@@ -550,9 +579,10 @@ PyObject * AerospikeClient_ListRemove(AerospikeClient * self, PyObject * args, P
 	as_operations_inita(&ops, 1);
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "meta", "policy", NULL};
+	static char *kwlist[] = {"key", "bin", "index", "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOl|OO:list_remove", kwlist,
-				&py_key, &py_bin, &index, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &index, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -584,7 +614,8 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListRemoveRange(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListRemoveRange(AerospikeClient *self, PyObject *args,
+										  PyObject *kwds)
 {
 	BASE_VARIABLES
 
@@ -594,9 +625,11 @@ PyObject * AerospikeClient_ListRemoveRange(AerospikeClient * self, PyObject * ar
 	as_operations_inita(&ops, 1);
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "count", "meta", "policy", NULL};
-	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOll|OO:list_remove_range", kwlist,
-				&py_key, &py_bin, &index, &count, &py_meta, &py_policy) == false) {
+	static char *kwlist[] = {"key",	 "bin",	   "index", "count",
+							 "meta", "policy", NULL};
+	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOll|OO:list_remove_range",
+									kwlist, &py_key, &py_bin, &index, &count,
+									&py_meta, &py_policy) == false) {
 		return NULL;
 	}
 
@@ -628,15 +661,17 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListClear(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListClear(AerospikeClient *self, PyObject *args,
+									PyObject *kwds)
 {
 	BASE_VARIABLES
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "meta", "policy", NULL};
+	static char *kwlist[] = {"key", "bin", "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OO|OO:list_clear", kwlist,
-				&py_key, &py_bin, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -668,18 +703,21 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListSet(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListSet(AerospikeClient *self, PyObject *args,
+								  PyObject *kwds)
 {
 	BASE_VARIABLES
 
-	PyObject * py_val = NULL;
+	PyObject *py_val = NULL;
 	uint64_t index;
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "val", "meta", "policy", NULL};
+	static char *kwlist[] = {"key",	 "bin",	   "index", "val",
+							 "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOlO|OO:list_set", kwlist,
-				&py_key, &py_bin, &index, &py_val, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &index, &py_val, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -690,9 +728,9 @@ PyObject * AerospikeClient_ListSet(AerospikeClient * self, PyObject * args, PyOb
 
 	POLICY_KEY_META_BIN();
 
-	as_val* put_val = NULL;
-	pyobject_to_astype_write(self, &err, py_val, &put_val,
-			&static_pool, SERIALIZER_PYTHON);
+	as_val *put_val = NULL;
+	pyobject_to_val(self, &err, py_val, &put_val, &static_pool,
+					SERIALIZER_PYTHON);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
@@ -720,7 +758,8 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListGet(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListGet(AerospikeClient *self, PyObject *args,
+								  PyObject *kwds)
 {
 	BASE_VARIABLES
 
@@ -729,9 +768,10 @@ PyObject * AerospikeClient_ListGet(AerospikeClient * self, PyObject * args, PyOb
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "meta", "policy", NULL};
+	static char *kwlist[] = {"key", "bin", "index", "meta", "policy", NULL};
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOl|OO:list_get", kwlist,
-				&py_key, &py_bin, &index, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &index, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -749,8 +789,10 @@ PyObject * AerospikeClient_ListGet(AerospikeClient * self, PyObject * args, PyOb
 
 	PyObject *py_val = NULL;
 	if (rec && rec->bins.size) {
-		val_to_pyobject(self, &err, (as_val*) (rec->bins.entries[0].valuep), &py_val);
-	} else {
+		val_to_pyobject(self, &err, (as_val *)(rec->bins.entries[0].valuep),
+						&py_val);
+	}
+	else {
 		py_val = Py_None;
 		Py_INCREF(py_val);
 	}
@@ -779,22 +821,25 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListGetRange(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListGetRange(AerospikeClient *self, PyObject *args,
+									   PyObject *kwds)
 {
 	BASE_VARIABLES
 
-	PyObject * py_list = NULL;
+	PyObject *py_list = NULL;
 	uint64_t index;
 	uint64_t count;
 	as_record *rec = NULL;
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "count", "meta", "policy", NULL};
+	static char *kwlist[] = {"key",	 "bin",	   "index", "count",
+							 "meta", "policy", NULL};
 
 	// Python Function Argument Parsing
-	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOll|OO:list_get_range", kwlist,
-				&py_key, &py_bin, &index, &count, &py_meta, &py_policy) == false) {
+	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOll|OO:list_get_range",
+									kwlist, &py_key, &py_bin, &index, &count,
+									&py_meta, &py_policy) == false) {
 		return NULL;
 	}
 
@@ -812,7 +857,8 @@ PyObject * AerospikeClient_ListGetRange(AerospikeClient * self, PyObject * args,
 
 	if (rec && rec->bins.size) {
 		list_to_pyobject(self, &err, as_record_get_list(rec, bin), &py_list);
-	} else if (rec && rec->bins.size == 0) {
+	}
+	else if (rec && rec->bins.size == 0) {
 		as_list *list = NULL;
 		list_to_pyobject(self, &err, list, &py_list);
 	}
@@ -841,7 +887,8 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_ListTrim(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_ListTrim(AerospikeClient *self, PyObject *args,
+								   PyObject *kwds)
 {
 	BASE_VARIABLES
 
@@ -851,11 +898,13 @@ PyObject * AerospikeClient_ListTrim(AerospikeClient * self, PyObject * args, PyO
 	as_operations ops;
 	as_operations_inita(&ops, 1);
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bin", "index", "count", "meta", "policy", NULL};
+	static char *kwlist[] = {"key",	 "bin",	   "index", "count",
+							 "meta", "policy", NULL};
 
 	// Python Function Argument Parsing
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OOll|OO:list_trim", kwlist,
-				&py_key, &py_bin, &index, &count, &py_meta, &py_policy) == false) {
+									&py_key, &py_bin, &index, &count, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -876,4 +925,3 @@ CLEANUP:
 
 	return PyLong_FromLong(0);
 }
-
