@@ -41,29 +41,25 @@
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-static
-PyObject * AerospikeClient_RemoveBin_Invoke(
-		AerospikeClient * self,
-		PyObject * py_key,PyObject* py_binList ,PyObject * py_policy, PyObject * py_meta, as_error *err)
+static PyObject *
+AerospikeClient_RemoveBin_Invoke(AerospikeClient *self, PyObject *py_key,
+								 PyObject *py_binList, PyObject *py_policy,
+								 PyObject *py_meta, as_error *err)
 {
 
 	// Aerospike Client Arguments
 	as_policy_write write_policy;
-	as_policy_write * write_policy_p = NULL;
+	as_policy_write *write_policy_p = NULL;
 	as_key key;
 	bool key_initialized = false;
 	as_record rec;
-	char* binName = NULL;
+	char *binName = NULL;
 	int count = 0;
-	PyObject * py_ustr = NULL;
+	PyObject *py_ustr = NULL;
 
 	// For converting expressions.
 	as_exp exp_list;
-	as_exp* exp_list_p = NULL;
-
-	// For converting predexp.
-	as_predexp_list predexp_list;
-	as_predexp_list* predexp_list_p = NULL;
+	as_exp *exp_list_p = NULL;
 
 	// Get the bin list size;
 	Py_ssize_t size = PyList_Size(py_binList);
@@ -78,8 +74,9 @@ PyObject * AerospikeClient_RemoveBin_Invoke(
 	key_initialized = true;
 
 	// Convert python policy object to as_policy_write
-	pyobject_to_policy_write(self, err, py_policy, &write_policy, &write_policy_p,
-			&self->as->config.policies.write, &predexp_list, &predexp_list_p, &exp_list, &exp_list_p);
+	pyobject_to_policy_write(self, err, py_policy, &write_policy,
+							 &write_policy_p, &self->as->config.policies.write,
+							 &exp_list, &exp_list_p);
 	if (err->code != AEROSPIKE_OK) {
 		as_error_update(err, AEROSPIKE_ERR_CLIENT, "Incorrect policy");
 		goto CLEANUP;
@@ -88,7 +85,7 @@ PyObject * AerospikeClient_RemoveBin_Invoke(
 	// Invoke operation
 
 	for (count = 0; count < size; count++) {
-		PyObject * py_val = PyList_GetItem(py_binList, count);
+		PyObject *py_val = PyList_GetItem(py_binList, count);
 		if (PyUnicode_Check(py_val)) {
 			py_ustr = PyUnicode_AsUTF8String(py_val);
 			binName = PyBytes_AsString(py_ustr);
@@ -96,10 +93,10 @@ PyObject * AerospikeClient_RemoveBin_Invoke(
 		else if (PyString_Check(py_val)) {
 			binName = PyString_AsString(py_val);
 		}
-		else
-		{
-			as_error_update(err, AEROSPIKE_ERR_CLIENT, "Invalid bin name, bin name should be a string or unicode string")
-			goto CLEANUP;
+		else {
+			as_error_update(err, AEROSPIKE_ERR_CLIENT,
+							"Invalid bin name, bin name should be a string or "
+							"unicode string") goto CLEANUP;
 		}
 		if (!as_record_set_nil(&rec, binName)) {
 			goto CLEANUP;
@@ -111,41 +108,45 @@ PyObject * AerospikeClient_RemoveBin_Invoke(
 	}
 
 	if (py_meta && PyDict_Check(py_meta)) {
-		PyObject * py_gen = PyDict_GetItemString(py_meta, "gen");
-		PyObject * py_ttl = PyDict_GetItemString(py_meta, "ttl");
+		PyObject *py_gen = PyDict_GetItemString(py_meta, "gen");
+		PyObject *py_ttl = PyDict_GetItemString(py_meta, "ttl");
 
 		if (py_ttl) {
 			if (PyInt_Check(py_ttl)) {
-				rec.ttl = (uint32_t) PyInt_AsLong(py_ttl);
+				rec.ttl = (uint32_t)PyInt_AsLong(py_ttl);
 			}
 			else if (PyLong_Check(py_ttl)) {
-				rec.ttl = (uint32_t) PyLong_AsLongLong(py_ttl);
+				rec.ttl = (uint32_t)PyLong_AsLongLong(py_ttl);
 				if ((uint32_t)-1 == rec.ttl && PyErr_Occurred()) {
-					as_error_update(err, AEROSPIKE_ERR_PARAM, "integer value for ttl exceeds sys.maxsize");
+					as_error_update(
+						err, AEROSPIKE_ERR_PARAM,
+						"integer value for ttl exceeds sys.maxsize");
 					goto CLEANUP;
 				}
 			}
-			else
-			{
-				as_error_update(err, AEROSPIKE_ERR_PARAM, "Ttl should be an int or long");
+			else {
+				as_error_update(err, AEROSPIKE_ERR_PARAM,
+								"Ttl should be an int or long");
 				goto CLEANUP;
 			}
 		}
 
 		if (py_gen) {
 			if (PyInt_Check(py_gen)) {
-				rec.gen = (uint16_t) PyInt_AsLong(py_gen);
+				rec.gen = (uint16_t)PyInt_AsLong(py_gen);
 			}
 			else if (PyLong_Check(py_gen)) {
-				rec.gen = (uint16_t) PyLong_AsLongLong(py_gen);
+				rec.gen = (uint16_t)PyLong_AsLongLong(py_gen);
 				if ((uint16_t)-1 == rec.gen && PyErr_Occurred()) {
-					as_error_update(err, AEROSPIKE_ERR_PARAM, "integer value for gen exceeds sys.maxsize");
+					as_error_update(
+						err, AEROSPIKE_ERR_PARAM,
+						"integer value for gen exceeds sys.maxsize");
 					goto CLEANUP;
 				}
 			}
-			else
-			{
-				as_error_update(err, AEROSPIKE_ERR_PARAM, "Generation should be an int or long");
+			else {
+				as_error_update(err, AEROSPIKE_ERR_PARAM,
+								"Generation should be an int or long");
 				goto CLEANUP;
 			}
 		}
@@ -164,11 +165,7 @@ CLEANUP:
 	as_record_destroy(&rec);
 
 	if (exp_list_p) {
-		as_exp_destroy(exp_list_p);;
-	}
-
-	if (predexp_list_p) {
-		as_predexp_list_destroy(&predexp_list);
+		as_exp_destroy(exp_list_p);
 	}
 
 	if (key_initialized) {
@@ -176,12 +173,12 @@ CLEANUP:
 	}
 
 	if (err->code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(err, &py_err);
 		PyObject *exception_type = raise_exception(err);
 		if (PyObject_HasAttrString(exception_type, "key")) {
 			PyObject_SetAttrString(exception_type, "key", py_key);
-		} 
+		}
 		if (PyObject_HasAttrString(exception_type, "bin")) {
 			PyObject_SetAttrString(exception_type, "bin", Py_None);
 		}
@@ -205,25 +202,27 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_RemoveBin(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_RemoveBin(AerospikeClient *self, PyObject *args,
+									PyObject *kwds)
 {
 	// Python Function Arguments
-	PyObject * py_key = NULL;
-	PyObject * py_policy = NULL;
-	PyObject * py_binList = NULL;
-	PyObject * py_result = NULL;
-	PyObject * py_meta = NULL;
+	PyObject *py_key = NULL;
+	PyObject *py_policy = NULL;
+	PyObject *py_binList = NULL;
+	PyObject *py_result = NULL;
+	PyObject *py_meta = NULL;
 
 	as_error err;
 	// Initialize error
 	as_error_init(&err);
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "list", "meta", "policy", NULL};
+	static char *kwlist[] = {"key", "list", "meta", "policy", NULL};
 
 	// Python Function Argument Parsing
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "OO|OO:remove_bin", kwlist,
-				&py_key, &py_binList ,&py_meta, &py_policy) == false) {
+									&py_key, &py_binList, &py_meta,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -233,7 +232,8 @@ PyObject * AerospikeClient_RemoveBin(AerospikeClient * self, PyObject * args, Py
 	}
 
 	if (!self->is_conn_16) {
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster");
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,
+						"No connection to aerospike cluster");
 		goto CLEANUP;
 	}
 
@@ -243,17 +243,18 @@ PyObject * AerospikeClient_RemoveBin(AerospikeClient * self, PyObject * args, Py
 	}
 
 	// Invoke Operation
-	return AerospikeClient_RemoveBin_Invoke(self, py_key, py_binList, py_policy, py_meta, &err);
+	return AerospikeClient_RemoveBin_Invoke(self, py_key, py_binList, py_policy,
+											py_meta, &err);
 
 CLEANUP:
 
 	if (err.code != AEROSPIKE_OK || !py_result) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		if (PyObject_HasAttrString(exception_type, "key")) {
 			PyObject_SetAttrString(exception_type, "key", py_key);
-		} 
+		}
 		if (PyObject_HasAttrString(exception_type, "bin")) {
 			PyObject_SetAttrString(exception_type, "bin", Py_None);
 		}
@@ -263,4 +264,3 @@ CLEANUP:
 	}
 	return NULL;
 }
-
