@@ -39,31 +39,26 @@
  * Returns a tuple containing key, meta and bins.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_Select_Invoke(
-	AerospikeClient * self,
-	PyObject * py_key, PyObject * py_bins, PyObject * py_policy)
+PyObject *AerospikeClient_Select_Invoke(AerospikeClient *self, PyObject *py_key,
+										PyObject *py_bins, PyObject *py_policy)
 {
 	// Python Return Value
-	PyObject * py_rec = NULL;
-	PyObject * py_ustr = NULL;
+	PyObject *py_rec = NULL;
+	PyObject *py_ustr = NULL;
 
 	// Aerospike Client Arguments
 	as_error err;
 	as_policy_read read_policy;
-	as_policy_read * read_policy_p = NULL;
+	as_policy_read *read_policy_p = NULL;
 	as_key key;
-	as_record * rec = NULL;
-    // It's only safe to free the record if this succeeded.
+	as_record *rec = NULL;
+	// It's only safe to free the record if this succeeded.
 	bool select_succeeded = false;
-	char ** bins = NULL;
+	char **bins = NULL;
 
 	// For converting expressions.
 	as_exp exp_list;
-	as_exp* exp_list_p = NULL;
-
-	// For converting predexp.
-	as_predexp_list predexp_list;
-	as_predexp_list* predexp_list_p = NULL;
+	as_exp *exp_list_p = NULL;
 
 	// Initialisation flags
 	bool key_initialised = false;
@@ -77,7 +72,8 @@ PyObject * AerospikeClient_Select_Invoke(
 	}
 
 	if (!self->is_conn_16) {
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster");
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,
+						"No connection to aerospike cluster");
 		goto CLEANUP;
 	}
 
@@ -92,21 +88,26 @@ PyObject * AerospikeClient_Select_Invoke(
 	// Convert python bins list to char ** bins
 	if (py_bins && PyList_Check(py_bins)) {
 		Py_ssize_t size = PyList_Size(py_bins);
-		bins = (char **) alloca(sizeof(char *) * (size+1));
+		bins = (char **)alloca(sizeof(char *) * (size + 1));
 		for (int i = 0; i < size; i++) {
-			PyObject * py_val = PyList_GetItem(py_bins, i);
-			bins[i] = (char *) alloca(sizeof(char) * AS_BIN_NAME_MAX_SIZE);
+			PyObject *py_val = PyList_GetItem(py_bins, i);
+			bins[i] = (char *)alloca(sizeof(char) * AS_BIN_NAME_MAX_SIZE);
 			if (PyString_Check(py_val)) {
-				strncpy(bins[i], PyString_AsString(py_val), AS_BIN_NAME_MAX_LEN);
+				strncpy(bins[i], PyString_AsString(py_val),
+						AS_BIN_NAME_MAX_LEN);
 				bins[i][AS_BIN_NAME_MAX_LEN] = '\0';
-			} else if (PyUnicode_Check(py_val)) {
+			}
+			else if (PyUnicode_Check(py_val)) {
 				py_ustr = PyUnicode_AsUTF8String(py_val);
-				strncpy(bins[i], PyString_AsString(py_val), AS_BIN_NAME_MAX_LEN);
+				strncpy(bins[i], PyString_AsString(py_val),
+						AS_BIN_NAME_MAX_LEN);
 				Py_CLEAR(py_ustr);
 				bins[i][AS_BIN_NAME_MAX_LEN] = '\0';
-			} else {
+			}
+			else {
 				// Bin name wasn't a string raise error and exit
-				as_error_update(&err, AEROSPIKE_ERR_PARAM, "Bin name must be a string");
+				as_error_update(&err, AEROSPIKE_ERR_PARAM,
+								"Bin name must be a string");
 				goto CLEANUP;
 			}
 		}
@@ -114,19 +115,23 @@ PyObject * AerospikeClient_Select_Invoke(
 	}
 	else if (py_bins && PyTuple_Check(py_bins)) {
 		Py_ssize_t size = PyTuple_Size(py_bins);
-		bins = (char **) alloca(sizeof(char *) * (size+1));
+		bins = (char **)alloca(sizeof(char *) * (size + 1));
 		for (int i = 0; i < size; i++) {
-			PyObject * py_val = PyTuple_GetItem(py_bins, i);
-			bins[i] = (char *) alloca(sizeof(char) * AS_BIN_NAME_MAX_SIZE);
+			PyObject *py_val = PyTuple_GetItem(py_bins, i);
+			bins[i] = (char *)alloca(sizeof(char) * AS_BIN_NAME_MAX_SIZE);
 			if (PyUnicode_Check(py_val)) {
 				py_ustr = PyUnicode_AsUTF8String(py_val);
-				strncpy(bins[i], PyBytes_AsString(py_ustr), AS_BIN_NAME_MAX_LEN);
+				strncpy(bins[i], PyBytes_AsString(py_ustr),
+						AS_BIN_NAME_MAX_LEN);
 				Py_CLEAR(py_ustr);
 				bins[i][AS_BIN_NAME_MAX_LEN] = '\0';
-			} else if (PyString_Check(py_val)) {
-				strncpy(bins[i], PyString_AsString(py_val), AS_BIN_NAME_MAX_LEN);
+			}
+			else if (PyString_Check(py_val)) {
+				strncpy(bins[i], PyString_AsString(py_val),
+						AS_BIN_NAME_MAX_LEN);
 				bins[i][AS_BIN_NAME_MAX_LEN] = '\0';
-			} else {
+			}
+			else {
 				as_error_update(&err, AEROSPIKE_ERR_PARAM, "not string type");
 				goto CLEANUP;
 			}
@@ -140,14 +145,16 @@ PyObject * AerospikeClient_Select_Invoke(
 
 	// Convert python policy object to as_policy_exists
 	pyobject_to_policy_read(self, &err, py_policy, &read_policy, &read_policy_p,
-			&self->as->config.policies.read, &predexp_list, &predexp_list_p, &exp_list, &exp_list_p);
+							&self->as->config.policies.read, &exp_list,
+							&exp_list_p);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
 
 	// Invoke operation
 	Py_BEGIN_ALLOW_THREADS
-	aerospike_key_select(self->as, &err, read_policy_p, &key, (const char **) bins, &rec);
+	aerospike_key_select(self->as, &err, read_policy_p, &key,
+						 (const char **)bins, &rec);
 	Py_END_ALLOW_THREADS
 
 	if (err.code == AEROSPIKE_OK) {
@@ -160,11 +167,8 @@ PyObject * AerospikeClient_Select_Invoke(
 
 CLEANUP:
 	if (exp_list_p) {
-		as_exp_destroy(exp_list_p);;
-	}
-
-	if (predexp_list_p) {
-		as_predexp_list_destroy(&predexp_list);
+		as_exp_destroy(exp_list_p);
+		;
 	}
 
 	if (py_ustr) {
@@ -181,12 +185,12 @@ CLEANUP:
 	}
 
 	if (err.code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		if (PyObject_HasAttrString(exception_type, "key")) {
 			PyObject_SetAttrString(exception_type, "key", py_key);
-		} 
+		}
 		if (PyObject_HasAttrString(exception_type, "bin")) {
 			PyObject_SetAttrString(exception_type, "bin", Py_None);
 		}
@@ -211,19 +215,20 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_Select(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_Select(AerospikeClient *self, PyObject *args,
+								 PyObject *kwds)
 {
 	// Python Function Arguments
-	PyObject * py_key = NULL;
-	PyObject * py_bins = NULL;
-	PyObject * py_policy = NULL;
+	PyObject *py_key = NULL;
+	PyObject *py_bins = NULL;
+	PyObject *py_policy = NULL;
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"key", "bins", "policy", NULL};
+	static char *kwlist[] = {"key", "bins", "policy", NULL};
 
 	// Python Function Argument Parsing
-	if (PyArg_ParseTupleAndKeywords(args, kwds, "OO|O:select", kwlist,
-			&py_key, &py_bins, &py_policy) == false) {
+	if (PyArg_ParseTupleAndKeywords(args, kwds, "OO|O:select", kwlist, &py_key,
+									&py_bins, &py_policy) == false) {
 		return NULL;
 	}
 
