@@ -18,13 +18,15 @@
 #include <aerospike/as_lookup.h>
 #include <aerospike/as_info.h>
 
-as_status
-send_info_to_tls_host(aerospike* as, as_error* err, const as_policy_info* info_policy,
-					  const char* hostname, uint16_t port, const char* tls_name,
-					  const char* request, char** response) {
+as_status send_info_to_tls_host(aerospike *as, as_error *err,
+								const as_policy_info *info_policy,
+								const char *hostname, uint16_t port,
+								const char *tls_name, const char *request,
+								char **response)
+{
 
 	as_status status = AEROSPIKE_OK;
-	as_cluster* cluster = as->cluster;
+	as_cluster *cluster = as->cluster;
 	as_address_iterator iter;
 
 	if (!cluster) {
@@ -37,7 +39,7 @@ send_info_to_tls_host(aerospike* as, as_error* err, const as_policy_info* info_p
 		return err->code;
 	}
 
-	struct sockaddr* addr;
+	struct sockaddr *addr;
 	status = AEROSPIKE_ERR_CLUSTER;
 	bool loop = true;
 
@@ -47,22 +49,22 @@ send_info_to_tls_host(aerospike* as, as_error* err, const as_policy_info* info_p
 	uint64_t deadline = as_socket_deadline(info_policy->timeout);
 
 	while (loop && as_lookup_next(&iter, &addr)) {
-		status = as_info_command_host(cluster, err, addr, (char*)request, info_policy->send_as_is,
-				deadline, response, tls_name);
+		status = as_info_command_host(cluster, err, addr, (char *)request,
+									  info_policy->send_as_is, deadline,
+									  response, tls_name);
 
 		switch (status) {
-			case AEROSPIKE_OK:
-			case AEROSPIKE_ERR_TIMEOUT:
-			case AEROSPIKE_ERR_INDEX_FOUND:
-			case AEROSPIKE_ERR_INDEX_NOT_FOUND:
-				loop = false;
-				break;
+		case AEROSPIKE_OK:
+		case AEROSPIKE_ERR_TIMEOUT:
+		case AEROSPIKE_ERR_INDEX_FOUND:
+		case AEROSPIKE_ERR_INDEX_NOT_FOUND:
+			loop = false;
+			break;
 
-			default:
-				break;
+		default:
+			break;
 		}
 	}
 	as_lookup_end(&iter);
 	return status;
-
 }
