@@ -33,7 +33,6 @@
 #include "exceptions.h"
 #include "policy.h"
 
-
 /**
  *******************************************************************************************************
  * Registers a UDF module with the Aerospike DB.
@@ -46,37 +45,38 @@
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_UDF_Put(AerospikeClient * self, PyObject *args, PyObject * kwds)
+PyObject *AerospikeClient_UDF_Put(AerospikeClient *self, PyObject *args,
+								  PyObject *kwds)
 {
 	// Initialize error
 	as_error err;
 	as_error_init(&err);
 
 	// Python Function Arguments
-	PyObject * py_filename = NULL;
+	PyObject *py_filename = NULL;
 	long language = 0;
-	PyObject * py_udf_type = NULL;
-	PyObject * py_policy = NULL;
-	PyObject * py_ustr = NULL;
+	PyObject *py_udf_type = NULL;
+	PyObject *py_policy = NULL;
+	PyObject *py_ustr = NULL;
 	// This lets each component be 255 characters, and allows a '/'' in between them
 	uint32_t max_copy_path_length = AS_CONFIG_PATH_MAX_SIZE * 2 - 1;
 	uint32_t filename_length = 0;
-	uint8_t * bytes = NULL;
+	uint8_t *bytes = NULL;
 	as_policy_info info_policy;
 	as_policy_info *info_policy_p = NULL;
-	FILE * file_p = NULL;
-	FILE * copy_file_p = NULL;
+	FILE *file_p = NULL;
+	FILE *copy_file_p = NULL;
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"filename", "udf_type", "policy", NULL};
+	static char *kwlist[] = {"filename", "udf_type", "policy", NULL};
 
 	// Python Function Argument Parsing
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "O|lO:udf_put", kwlist,
-				&py_filename, &language, &py_policy) == false) {
+									&py_filename, &language,
+									&py_policy) == false) {
 		return NULL;
 	}
 
-	if (language != AS_UDF_TYPE_LUA)
-	{
+	if (language != AS_UDF_TYPE_LUA) {
 		as_error_update(&err, AEROSPIKE_ERR_CLIENT, "Invalid UDF language");
 		goto CLEANUP;
 	}
@@ -88,7 +88,8 @@ PyObject * AerospikeClient_UDF_Put(AerospikeClient * self, PyObject *args, PyObj
 	}
 
 	if (!self->is_conn_16) {
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster");
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,
+						"No connection to aerospike cluster");
 		goto CLEANUP;
 	}
 
@@ -97,16 +98,19 @@ PyObject * AerospikeClient_UDF_Put(AerospikeClient * self, PyObject *args, PyObj
 	if (PyUnicode_Check(py_filename)) {
 		py_ustr = PyUnicode_AsUTF8String(py_filename);
 		filename = PyBytes_AsString(py_ustr);
-	} else if (PyString_Check(py_filename)) {
+	}
+	else if (PyString_Check(py_filename)) {
 		filename = PyString_AsString(py_filename);
-	} else {
-		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Filename should be a string");
+	}
+	else {
+		as_error_update(&err, AEROSPIKE_ERR_PARAM,
+						"Filename should be a string");
 		goto CLEANUP;
 	}
 
 	// Convert python object to policy_info
-	pyobject_to_policy_info( &err, py_policy, &info_policy, &info_policy_p,
-			&self->as->config.policies.info);
+	pyobject_to_policy_info(&err, py_policy, &info_policy, &info_policy_p,
+							&self->as->config.policies.info);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
@@ -114,49 +118,52 @@ PyObject * AerospikeClient_UDF_Put(AerospikeClient * self, PyObject *args, PyObj
 
 	// Convert lua file to content
 	as_bytes content;
-	file_p = fopen(filename,"r");
+	file_p = fopen(filename, "r");
 
 	// Make this equal to twice the path size, so the path and the filename
 	// may be 255 characters each. The max size should then be 255 + 255 + 1 + 1
 	char copy_filepath[AS_CONFIG_PATH_MAX_SIZE * 2] = {0};
 	uint32_t user_path_len = strlen(self->as->config.lua.user_path);
-	memcpy( copy_filepath,
-		self->as->config.lua.user_path,
-		user_path_len);
-	if (self->as->config.lua.user_path[user_path_len-1] != '/') {
-		memcpy( copy_filepath + user_path_len, "/", 1);
+	memcpy(copy_filepath, self->as->config.lua.user_path, user_path_len);
+	if (self->as->config.lua.user_path[user_path_len - 1] != '/') {
+		memcpy(copy_filepath + user_path_len, "/", 1);
 		user_path_len = user_path_len + 1;
 	}
-	char* extracted_filename = strrchr(filename, '/');
+	char *extracted_filename = strrchr(filename, '/');
 	if (extracted_filename) {
-		filename_length = strlen(extracted_filename) - 1; // Length of the filename after the last '/'
+		filename_length = strlen(extracted_filename) -
+						  1; // Length of the filename after the last '/'
 		if (!filename_length) {
 			as_error_update(&err, AEROSPIKE_ERR_PARAM, "Empty udf filename");
 			goto CLEANUP;
 		}
 		if (user_path_len + filename_length > max_copy_path_length) {
-			as_error_update(&err, AEROSPIKE_ERR_PARAM, "Lua file pathname too long");
+			as_error_update(&err, AEROSPIKE_ERR_PARAM,
+							"Lua file pathname too long");
 			goto CLEANUP;
 		}
-		memcpy( copy_filepath + user_path_len, extracted_filename + 1, strlen(extracted_filename) - 1);
+		memcpy(copy_filepath + user_path_len, extracted_filename + 1,
+			   strlen(extracted_filename) - 1);
 		copy_filepath[user_path_len + strlen(extracted_filename) - 1] = '\0';
-	} else {
+	}
+	else {
 		filename_length = strlen(filename);
 		if (!filename_length) {
 			as_error_update(&err, AEROSPIKE_ERR_PARAM, "Empty udf filename");
 			goto CLEANUP;
 		}
 		if (user_path_len + filename_length > max_copy_path_length) {
-			as_error_update(&err, AEROSPIKE_ERR_PARAM, "Lua file pathname too long");
+			as_error_update(&err, AEROSPIKE_ERR_PARAM,
+							"Lua file pathname too long");
 			goto CLEANUP;
 		}
-		memcpy( copy_filepath + user_path_len, filename, strlen(filename));
+		memcpy(copy_filepath + user_path_len, filename, strlen(filename));
 		copy_filepath[user_path_len + strlen(filename)] = '\0';
 	}
 
-
 	if (!file_p) {
-		as_error_update(&err, AEROSPIKE_ERR_LUA_FILE_NOT_FOUND, "cannot open script file");
+		as_error_update(&err, AEROSPIKE_ERR_LUA_FILE_NOT_FOUND,
+						"cannot open script file");
 		goto CLEANUP;
 	}
 
@@ -164,20 +171,22 @@ PyObject * AerospikeClient_UDF_Put(AerospikeClient * self, PyObject *args, PyObj
 	int fileSize = ftell(file_p);
 	fseek(file_p, 0, SEEK_SET);
 	if (fileSize <= 0) {
-		as_error_update(&err, AEROSPIKE_ERR_LUA_FILE_NOT_FOUND, "Script file is empty");
+		as_error_update(&err, AEROSPIKE_ERR_LUA_FILE_NOT_FOUND,
+						"Script file is empty");
 		fclose(file_p);
 		file_p = NULL;
 		goto CLEANUP;
 	}
 
 	if (fileSize >= SCRIPT_LEN_MAX) {
-		as_error_update(&err, AEROSPIKE_ERR_LUA_FILE_NOT_FOUND, "Script File is too large");
+		as_error_update(&err, AEROSPIKE_ERR_LUA_FILE_NOT_FOUND,
+						"Script File is too large");
 		fclose(file_p);
 		file_p = NULL;
 		goto CLEANUP;
 	}
 
-	bytes = (uint8_t *) malloc(SCRIPT_LEN_MAX);
+	bytes = (uint8_t *)malloc(SCRIPT_LEN_MAX);
 	if (!bytes) {
 		as_error_update(&err, errno, "malloc failed");
 		goto CLEANUP;
@@ -185,13 +194,13 @@ PyObject * AerospikeClient_UDF_Put(AerospikeClient * self, PyObject *args, PyObj
 
 	int size = 0;
 
-	uint8_t * buff = bytes;
+	uint8_t *buff = bytes;
 
 	if (access(self->as->config.lua.user_path, W_OK) == 0) {
 
 		copy_file_p = fopen(copy_filepath, "w+");
 		if (copy_file_p) {
-			int read  = (int)fread(buff, 1, LUA_FILE_BUFFER_FRAME, file_p);
+			int read = (int)fread(buff, 1, LUA_FILE_BUFFER_FRAME, file_p);
 			if (read && fwrite(buff, 1, read, copy_file_p)) {
 				while (read) {
 					size += read;
@@ -201,16 +210,22 @@ PyObject * AerospikeClient_UDF_Put(AerospikeClient * self, PyObject *args, PyObj
 						break;
 					}
 				}
-			} else {
-				as_error_update(&err, AEROSPIKE_ERR_CLIENT, "Write of lua file to user path failed");
+			}
+			else {
+				as_error_update(&err, AEROSPIKE_ERR_CLIENT,
+								"Write of lua file to user path failed");
 				goto CLEANUP;
 			}
-		} else {
-			as_error_update(&err, AEROSPIKE_ERR_CLIENT, "Write of lua file to user path failed");
+		}
+		else {
+			as_error_update(&err, AEROSPIKE_ERR_CLIENT,
+							"Write of lua file to user path failed");
 			goto CLEANUP;
 		}
-	} else {
-		as_error_update(&err, AEROSPIKE_ERR_CLIENT, "No permissions to write lua file to user path");
+	}
+	else {
+		as_error_update(&err, AEROSPIKE_ERR_CLIENT,
+						"No permissions to write lua file to user path");
 		goto CLEANUP;
 	}
 
@@ -218,13 +233,16 @@ PyObject * AerospikeClient_UDF_Put(AerospikeClient * self, PyObject *args, PyObj
 
 	// Invoke operation
 	Py_BEGIN_ALLOW_THREADS
-	aerospike_udf_put(self->as, &err, info_policy_p, filename, udf_type, &content);
+	aerospike_udf_put(self->as, &err, info_policy_p, filename, udf_type,
+					  &content);
 	Py_END_ALLOW_THREADS
 	if (err.code != AEROSPIKE_OK) {
 		as_error_update(&err, err.code, NULL);
 		goto CLEANUP;
-	} else {
-		aerospike_udf_put_wait(self->as, &err, info_policy_p, as_basename(NULL, filename), 2000);
+	}
+	else {
+		aerospike_udf_put_wait(self->as, &err, info_policy_p,
+							   as_basename(NULL, filename), 2000);
 	}
 
 CLEANUP:
@@ -244,12 +262,12 @@ CLEANUP:
 	}
 
 	if (err.code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		if (PyObject_HasAttrString(exception_type, "module")) {
 			PyObject_SetAttrString(exception_type, "module", Py_None);
-		} 
+		}
 		if (PyObject_HasAttrString(exception_type, "func")) {
 			PyObject_SetAttrString(exception_type, "func", Py_None);
 		}
@@ -274,26 +292,27 @@ CLEANUP:
  * In case of error,appropriate exceptions will be raised.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_UDF_Remove(AerospikeClient * self, PyObject *args, PyObject * kwds)
+PyObject *AerospikeClient_UDF_Remove(AerospikeClient *self, PyObject *args,
+									 PyObject *kwds)
 {
 	// Initialize error
 	as_error err;
 	as_error_init(&err);
 
 	// Python Function Arguments
-	PyObject * py_policy = NULL;
-	PyObject * py_filename = NULL;
-	PyObject * py_ustr = NULL;
+	PyObject *py_policy = NULL;
+	PyObject *py_filename = NULL;
+	PyObject *py_ustr = NULL;
 
 	as_policy_info info_policy;
 	as_policy_info *info_policy_p = NULL;
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"filename", "policy", NULL};
+	static char *kwlist[] = {"filename", "policy", NULL};
 
 	// Python Function Argument Parsing
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "O|O:udf_remove", kwlist,
-				&py_filename, &py_policy) == false) {
+									&py_filename, &py_policy) == false) {
 		return NULL;
 	}
 
@@ -303,7 +322,8 @@ PyObject * AerospikeClient_UDF_Remove(AerospikeClient * self, PyObject *args, Py
 	}
 
 	if (!self->is_conn_16) {
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster");
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,
+						"No connection to aerospike cluster");
 		goto CLEANUP;
 	}
 
@@ -316,16 +336,19 @@ PyObject * AerospikeClient_UDF_Remove(AerospikeClient * self, PyObject *args, Py
 	if (PyUnicode_Check(py_filename)) {
 		py_ustr = PyUnicode_AsUTF8String(py_filename);
 		filename = PyBytes_AsString(py_ustr);
-	} else if (PyString_Check(py_filename)) {
+	}
+	else if (PyString_Check(py_filename)) {
 		filename = PyString_AsString(py_filename);
-	} else {
-		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Filename should be a string");
+	}
+	else {
+		as_error_update(&err, AEROSPIKE_ERR_PARAM,
+						"Filename should be a string");
 		goto CLEANUP;
 	}
 
 	// Convert python object to policy_info
-	pyobject_to_policy_info( &err, py_policy, &info_policy, &info_policy_p,
-			&self->as->config.policies.info);
+	pyobject_to_policy_info(&err, py_policy, &info_policy, &info_policy_p,
+							&self->as->config.policies.info);
 
 	// Invoke operation
 	Py_BEGIN_ALLOW_THREADS
@@ -342,12 +365,12 @@ CLEANUP:
 		Py_DECREF(py_ustr);
 	}
 	if (err.code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		if (PyObject_HasAttrString(exception_type, "module")) {
 			PyObject_SetAttrString(exception_type, "module", py_filename);
-		} 
+		}
 		if (PyObject_HasAttrString(exception_type, "func")) {
 			PyObject_SetAttrString(exception_type, "func", Py_None);
 		}
@@ -371,7 +394,8 @@ CLEANUP:
  * Returns list of modules that are registered with Aerospike DB.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_UDF_List(AerospikeClient * self, PyObject *args, PyObject * kwds)
+PyObject *AerospikeClient_UDF_List(AerospikeClient *self, PyObject *args,
+								   PyObject *kwds)
 {
 	// Initialize error
 	as_error err;
@@ -379,15 +403,16 @@ PyObject * AerospikeClient_UDF_List(AerospikeClient * self, PyObject *args, PyOb
 	int init_udf_files = 0;
 
 	// Python Function Arguments
-	PyObject * py_policy = NULL;
+	PyObject *py_policy = NULL;
 	as_policy_info info_policy;
 	as_policy_info *info_policy_p = NULL;
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"policy", NULL};
+	static char *kwlist[] = {"policy", NULL};
 
 	// Python Function Argument Parsing
-	if (PyArg_ParseTupleAndKeywords(args, kwds, "|O:udf_list", kwlist, &py_policy) == false) {
+	if (PyArg_ParseTupleAndKeywords(args, kwds, "|O:udf_list", kwlist,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -397,13 +422,14 @@ PyObject * AerospikeClient_UDF_List(AerospikeClient * self, PyObject *args, PyOb
 	}
 
 	if (!self->is_conn_16) {
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster");
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,
+						"No connection to aerospike cluster");
 		goto CLEANUP;
 	}
 
 	// Convert python object to policy_info
-	pyobject_to_policy_info( &err, py_policy, &info_policy, &info_policy_p,
-			&self->as->config.policies.info);
+	pyobject_to_policy_info(&err, py_policy, &info_policy, &info_policy_p,
+							&self->as->config.policies.info);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
@@ -422,7 +448,7 @@ PyObject * AerospikeClient_UDF_List(AerospikeClient * self, PyObject *args, PyOb
 	}
 
 	// Convert as_udf_files struct into python object
-	PyObject * py_files;
+	PyObject *py_files;
 	as_udf_files_to_pyobject(&err, &files, &py_files);
 
 	if (err.code != AEROSPIKE_OK) {
@@ -437,12 +463,12 @@ CLEANUP:
 	}
 
 	if (err.code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		if (PyObject_HasAttrString(exception_type, "module")) {
 			PyObject_SetAttrString(exception_type, "module", Py_None);
-		} 
+		}
 		if (PyObject_HasAttrString(exception_type, "func")) {
 			PyObject_SetAttrString(exception_type, "func", Py_None);
 		}
@@ -466,26 +492,28 @@ CLEANUP:
  * Returns the content of the UDF module.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_UDF_Get_UDF(AerospikeClient * self, PyObject *args, PyObject * kwds)
+PyObject *AerospikeClient_UDF_Get_UDF(AerospikeClient *self, PyObject *args,
+									  PyObject *kwds)
 {
 	// Initialize error
 	as_error err;
 	as_error_init(&err);
 
 	// Python Function Arguments
-	PyObject * py_module = NULL;
-	PyObject * py_policy = NULL;
+	PyObject *py_module = NULL;
+	PyObject *py_policy = NULL;
 	long language = 0;
 	bool init_udf_file = false;
-	PyObject * udf_content = NULL;
-	PyObject * py_ustr = NULL;
+	PyObject *udf_content = NULL;
+	PyObject *py_ustr = NULL;
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"module", "language", "policy", NULL};
+	static char *kwlist[] = {"module", "language", "policy", NULL};
 
 	// Python Function Argument Parsing
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "O|lO:udf_get", kwlist,
-				&py_module ,&language, &py_policy) == false) {
+									&py_module, &language,
+									&py_policy) == false) {
 		return NULL;
 	}
 
@@ -495,16 +523,16 @@ PyObject * AerospikeClient_UDF_Get_UDF(AerospikeClient * self, PyObject *args, P
 	}
 
 	if (!self->is_conn_16) {
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster");
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,
+						"No connection to aerospike cluster");
 		goto CLEANUP;
 	}
 
-	if (language != AS_UDF_TYPE_LUA)
-	{
+	if (language != AS_UDF_TYPE_LUA) {
 		as_error_update(&err, AEROSPIKE_ERR_CLIENT, "Invalid language");
 		goto CLEANUP;
 	}
-	char* strModule = NULL;
+	char *strModule = NULL;
 	if (PyUnicode_Check(py_module)) {
 		py_ustr = PyUnicode_AsUTF8String(py_module);
 		strModule = PyBytes_AsString(py_ustr);
@@ -512,28 +540,29 @@ PyObject * AerospikeClient_UDF_Get_UDF(AerospikeClient * self, PyObject *args, P
 	else if (PyString_Check(py_module)) {
 		strModule = PyString_AsString(py_module);
 	}
-	else
-	{
-		as_error_update(&err, AEROSPIKE_ERR_CLIENT, "Module name should be a string or unicode string.");
+	else {
+		as_error_update(&err, AEROSPIKE_ERR_CLIENT,
+						"Module name should be a string or unicode string.");
 		goto CLEANUP;
 	}
 
 	// Convert python object to policy_info
 	as_policy_info *info_policy_p = NULL, info_policy;
 
-	pyobject_to_policy_info( &err, py_policy, &info_policy, &info_policy_p,
-			&self->as->config.policies.info);
+	pyobject_to_policy_info(&err, py_policy, &info_policy, &info_policy_p,
+							&self->as->config.policies.info);
 	if (err.code != AEROSPIKE_OK) {
 		goto CLEANUP;
 	}
 
 	as_udf_file file;
 	as_udf_file_init(&file);
-	init_udf_file=true;
+	init_udf_file = true;
 
 	// Invoke operation
 	Py_BEGIN_ALLOW_THREADS
-	aerospike_udf_get(self->as, &err, info_policy_p, strModule, (language - AS_UDF_TYPE_LUA) , &file);
+	aerospike_udf_get(self->as, &err, info_policy_p, strModule,
+					  (language - AS_UDF_TYPE_LUA), &file);
 	Py_END_ALLOW_THREADS
 	if (err.code != AEROSPIKE_OK) {
 		as_error_update(&err, err.code, NULL);
@@ -550,12 +579,12 @@ CLEANUP:
 		as_udf_file_destroy(&file);
 	}
 	if (err.code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		if (PyObject_HasAttrString(exception_type, "module")) {
 			PyObject_SetAttrString(exception_type, "module", py_module);
-		} 
+		}
 		if (PyObject_HasAttrString(exception_type, "func")) {
 			PyObject_SetAttrString(exception_type, "func", Py_None);
 		}
