@@ -26,27 +26,32 @@
 #include "geo.h"
 #include "policy.h"
 
-PyObject * AerospikeGeospatial_DoLoads(PyObject *py_geodata, as_error *err)
+PyObject *AerospikeGeospatial_DoLoads(PyObject *py_geodata, as_error *err)
 {
-	PyObject* sysmodules = PyImport_GetModuleDict();
-	PyObject* json_module = NULL;
+	PyObject *sysmodules = PyImport_GetModuleDict();
+	PyObject *json_module = NULL;
 	if (PyMapping_HasKeyString(sysmodules, "json")) {
 		json_module = PyMapping_GetItemString(sysmodules, "json");
-	} else {
+	}
+	else {
 		json_module = PyImport_ImportModule("json");
 	}
 
-	PyObject* initresult = NULL;
+	PyObject *initresult = NULL;
 	if (!json_module) {
 		/* insert error handling here! and exit this function */
-		as_error_update(err, AEROSPIKE_ERR_CLIENT, "Unable to load json module");
-	} else {
+		as_error_update(err, AEROSPIKE_ERR_CLIENT,
+						"Unable to load json module");
+	}
+	else {
 		PyObject *py_funcname = PyString_FromString("loads");
 		Py_INCREF(json_module);
 
-		initresult = PyObject_CallMethodObjArgs(json_module, py_funcname, py_geodata, NULL);
+		initresult = PyObject_CallMethodObjArgs(json_module, py_funcname,
+												py_geodata, NULL);
 		if (!initresult) {
-			as_error_update(err, AEROSPIKE_ERR_CLIENT, "Unable to load GeoJSON");
+			as_error_update(err, AEROSPIKE_ERR_CLIENT,
+							"Unable to load GeoJSON");
 		}
 		Py_DECREF(json_module);
 		Py_DECREF(py_funcname);
@@ -54,15 +59,17 @@ PyObject * AerospikeGeospatial_DoLoads(PyObject *py_geodata, as_error *err)
 	return initresult;
 }
 
-PyObject * AerospikeGeospatial_Loads(AerospikeGeospatial * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeGeospatial_Loads(AerospikeGeospatial *self, PyObject *args,
+									PyObject *kwds)
 {
 
 	// Python function arguments
-	PyObject * py_geodata = NULL;
+	PyObject *py_geodata = NULL;
 	// Python function keyword arguments
-	static char * kwlist[] = {"geodata", NULL};
+	static char *kwlist[] = {"geodata", NULL};
 
-	if (PyArg_ParseTupleAndKeywords(args, kwds, "O:loads", kwlist, &py_geodata) == false) {
+	if (PyArg_ParseTupleAndKeywords(args, kwds, "O:loads", kwlist,
+									&py_geodata) == false) {
 		return NULL;
 	}
 
@@ -76,18 +83,21 @@ PyObject * AerospikeGeospatial_Loads(AerospikeGeospatial * self, PyObject * args
 		goto CLEANUP;
 	}
 
-	PyObject* initresult = NULL;
-	if (PyString_Check(py_geodata))
-	{
+	PyObject *initresult = NULL;
+	if (PyString_Check(py_geodata)) {
 		initresult = AerospikeGeospatial_DoLoads(py_geodata, &err);
-		if(!initresult) {
-			as_error_update(&err, AEROSPIKE_ERR_CLIENT, "String is not GeoJSON serializable");
+		if (!initresult) {
+			as_error_update(&err, AEROSPIKE_ERR_CLIENT,
+							"String is not GeoJSON serializable");
 			goto CLEANUP;
-		} else {
+		}
+		else {
 			store_geodata(self, &err, initresult);
 		}
-	} else {
-		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Argument should be a GeoJSON string");
+	}
+	else {
+		as_error_update(&err, AEROSPIKE_ERR_PARAM,
+						"Argument should be a GeoJSON string");
 		goto CLEANUP;
 	}
 
@@ -95,7 +105,7 @@ CLEANUP:
 
 	// If an error occurred, tell Python.
 	if (err.code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		PyErr_SetObject(exception_type, py_err);
@@ -105,4 +115,3 @@ CLEANUP:
 
 	return PyLong_FromLong(0);
 }
-
