@@ -15,73 +15,84 @@
  ******************************************************************************/
 #include "policy_config.h"
 
-as_status set_optional_key(as_policy_key* target_ptr, PyObject* py_policy, const char* name);
-as_status set_optional_replica(as_policy_replica* target_ptr, PyObject* py_policy, const char* name);
-as_status set_optional_commit_level(as_policy_commit_level* target_ptr, PyObject* py_policy, const char* name);
-as_status set_optional_ap_read_mode(as_policy_read_mode_ap* target_ptr, PyObject* py_policy, const char* name);
-as_status set_optional_sc_read_mode(as_policy_read_mode_sc* target_ptr, PyObject* py_policy, const char* name);
-as_status set_optional_gen(as_policy_gen* target_ptr, PyObject* py_policy, const char* name);
-as_status set_optional_exists(as_policy_exists* target_ptr, PyObject* py_policy, const char* name);
-as_status get_uint32_value(PyObject* py_policy_val, uint32_t* return_uint32);
+as_status set_optional_key(as_policy_key *target_ptr, PyObject *py_policy,
+						   const char *name);
+as_status set_optional_replica(as_policy_replica *target_ptr,
+							   PyObject *py_policy, const char *name);
+as_status set_optional_commit_level(as_policy_commit_level *target_ptr,
+									PyObject *py_policy, const char *name);
+as_status set_optional_ap_read_mode(as_policy_read_mode_ap *target_ptr,
+									PyObject *py_policy, const char *name);
+as_status set_optional_sc_read_mode(as_policy_read_mode_sc *target_ptr,
+									PyObject *py_policy, const char *name);
+as_status set_optional_gen(as_policy_gen *target_ptr, PyObject *py_policy,
+						   const char *name);
+as_status set_optional_exists(as_policy_exists *target_ptr, PyObject *py_policy,
+							  const char *name);
+as_status get_uint32_value(PyObject *py_policy_val, uint32_t *return_uint32);
 /*
  * py_policies must exist, and be a dictionary
  */
-as_status set_subpolicies(as_config* config, PyObject* py_policies) {
+as_status set_subpolicies(as_config *config, PyObject *py_policies)
+{
 
-	 as_status set_policy_status = AEROSPIKE_OK;
+	as_status set_policy_status = AEROSPIKE_OK;
 
-	 PyObject* read_policy = PyDict_GetItemString(py_policies, "read");
-	 set_policy_status = set_read_policy(&config->policies.read, read_policy);
-	 if (set_policy_status != AEROSPIKE_OK) {
-		 return set_policy_status;
-	 }
+	PyObject *read_policy = PyDict_GetItemString(py_policies, "read");
+	set_policy_status = set_read_policy(&config->policies.read, read_policy);
+	if (set_policy_status != AEROSPIKE_OK) {
+		return set_policy_status;
+	}
 
-	 PyObject* write_policy = PyDict_GetItemString(py_policies, "write");
-	 set_policy_status = set_write_policy(&config->policies.write, write_policy);
-	 if (set_policy_status != AEROSPIKE_OK) {
-		 return set_policy_status;
-	 }
+	PyObject *write_policy = PyDict_GetItemString(py_policies, "write");
+	set_policy_status = set_write_policy(&config->policies.write, write_policy);
+	if (set_policy_status != AEROSPIKE_OK) {
+		return set_policy_status;
+	}
 
-	 PyObject* apply_policy = PyDict_GetItemString(py_policies, "apply");
-	 set_policy_status = set_apply_policy(&config->policies.apply, apply_policy);
-	 if (set_policy_status != AEROSPIKE_OK) {
-		 return set_policy_status;
-	 }
+	PyObject *apply_policy = PyDict_GetItemString(py_policies, "apply");
+	set_policy_status = set_apply_policy(&config->policies.apply, apply_policy);
+	if (set_policy_status != AEROSPIKE_OK) {
+		return set_policy_status;
+	}
 
-	 PyObject* remove_policy = PyDict_GetItemString(py_policies, "remove");
-	 set_policy_status = set_remove_policy(&config->policies.remove, remove_policy);
-	 if (set_policy_status != AEROSPIKE_OK) {
-		 return set_policy_status;
-	 }
+	PyObject *remove_policy = PyDict_GetItemString(py_policies, "remove");
+	set_policy_status =
+		set_remove_policy(&config->policies.remove, remove_policy);
+	if (set_policy_status != AEROSPIKE_OK) {
+		return set_policy_status;
+	}
 
-	 PyObject* query_policy = PyDict_GetItemString(py_policies, "query");
-	 set_policy_status = set_query_policy(&config->policies.query, query_policy);
-	 if (set_policy_status != AEROSPIKE_OK) {
-		 return set_policy_status;
-	 }
+	PyObject *query_policy = PyDict_GetItemString(py_policies, "query");
+	set_policy_status = set_query_policy(&config->policies.query, query_policy);
+	if (set_policy_status != AEROSPIKE_OK) {
+		return set_policy_status;
+	}
 
-	 PyObject* scan_policy = PyDict_GetItemString(py_policies, "scan");
-	 set_policy_status = set_scan_policy(&config->policies.scan, scan_policy);
-	 if (set_policy_status != AEROSPIKE_OK) {
-		 return set_policy_status;
-	 }
+	PyObject *scan_policy = PyDict_GetItemString(py_policies, "scan");
+	set_policy_status = set_scan_policy(&config->policies.scan, scan_policy);
+	if (set_policy_status != AEROSPIKE_OK) {
+		return set_policy_status;
+	}
 
-	 PyObject* operate_policy = PyDict_GetItemString(py_policies, "operate");
-	 set_policy_status = set_operate_policy(&config->policies.operate, operate_policy);
-	 if (set_policy_status != AEROSPIKE_OK) {
-		 return set_policy_status;
-	 }
+	PyObject *operate_policy = PyDict_GetItemString(py_policies, "operate");
+	set_policy_status =
+		set_operate_policy(&config->policies.operate, operate_policy);
+	if (set_policy_status != AEROSPIKE_OK) {
+		return set_policy_status;
+	}
 
-	 PyObject* batch_policy = PyDict_GetItemString(py_policies, "batch");
-	 set_policy_status = set_batch_policy(&config->policies.batch, batch_policy);
-	 if (set_policy_status != AEROSPIKE_OK) {
-		 return set_policy_status;
-	 }
+	PyObject *batch_policy = PyDict_GetItemString(py_policies, "batch");
+	set_policy_status = set_batch_policy(&config->policies.batch, batch_policy);
+	if (set_policy_status != AEROSPIKE_OK) {
+		return set_policy_status;
+	}
 
-	 return AEROSPIKE_OK;
+	return AEROSPIKE_OK;
 }
 
-as_status set_read_policy(as_policy_read* read_policy, PyObject* py_policy) {
+as_status set_read_policy(as_policy_read *read_policy, PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 	if (!py_policy) {
@@ -107,18 +118,20 @@ as_status set_read_policy(as_policy_read* read_policy, PyObject* py_policy) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&read_policy->deserialize, py_policy, "deserialize");
+	status = set_optional_bool_property(&read_policy->deserialize, py_policy,
+										"deserialize");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-
-	status = set_optional_ap_read_mode(&read_policy->read_mode_ap, py_policy, "read_mode_ap");
+	status = set_optional_ap_read_mode(&read_policy->read_mode_ap, py_policy,
+									   "read_mode_ap");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_sc_read_mode(&read_policy->read_mode_sc, py_policy, "read_mode_sc");
+	status = set_optional_sc_read_mode(&read_policy->read_mode_sc, py_policy,
+									   "read_mode_sc");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -126,7 +139,8 @@ as_status set_read_policy(as_policy_read* read_policy, PyObject* py_policy) {
 	return AEROSPIKE_OK;
 }
 
-as_status set_write_policy(as_policy_write* write_policy, PyObject* py_policy) {
+as_status set_write_policy(as_policy_write *write_policy, PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 
@@ -153,7 +167,8 @@ as_status set_write_policy(as_policy_write* write_policy, PyObject* py_policy) {
 		return status;
 	}
 
-	status = set_optional_commit_level(&write_policy->commit_level, py_policy, "commit_level");
+	status = set_optional_commit_level(&write_policy->commit_level, py_policy,
+									   "commit_level");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -168,12 +183,15 @@ as_status set_write_policy(as_policy_write* write_policy, PyObject* py_policy) {
 		return status;
 	}
 
-	status = set_optional_uint32_property((uint32_t*)&write_policy->compression_threshold, py_policy, "compression_threshold");
+	status = set_optional_uint32_property(
+		(uint32_t *)&write_policy->compression_threshold, py_policy,
+		"compression_threshold");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&write_policy->durable_delete, py_policy, "durable_delete");
+	status = set_optional_bool_property(&write_policy->durable_delete,
+										py_policy, "durable_delete");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -181,7 +199,8 @@ as_status set_write_policy(as_policy_write* write_policy, PyObject* py_policy) {
 	return AEROSPIKE_OK;
 }
 
-as_status set_apply_policy(as_policy_apply* apply_policy, PyObject* py_policy) {
+as_status set_apply_policy(as_policy_apply *apply_policy, PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 
@@ -208,12 +227,14 @@ as_status set_apply_policy(as_policy_apply* apply_policy, PyObject* py_policy) {
 		return status;
 	}
 
-	status = set_optional_commit_level(&apply_policy->commit_level, py_policy, "commit_level");
+	status = set_optional_commit_level(&apply_policy->commit_level, py_policy,
+									   "commit_level");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&apply_policy->durable_delete, py_policy, "durable_delete");
+	status = set_optional_bool_property(&apply_policy->durable_delete,
+										py_policy, "durable_delete");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -221,7 +242,9 @@ as_status set_apply_policy(as_policy_apply* apply_policy, PyObject* py_policy) {
 	return AEROSPIKE_OK;
 }
 
-as_status set_remove_policy(as_policy_remove* remove_policy, PyObject* py_policy) {
+as_status set_remove_policy(as_policy_remove *remove_policy,
+							PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 
@@ -243,12 +266,14 @@ as_status set_remove_policy(as_policy_remove* remove_policy, PyObject* py_policy
 		return status;
 	}
 
-	status = set_optional_replica(&remove_policy->replica, py_policy, "replica");
+	status =
+		set_optional_replica(&remove_policy->replica, py_policy, "replica");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_commit_level(&remove_policy->commit_level, py_policy, "commit_level");
+	status = set_optional_commit_level(&remove_policy->commit_level, py_policy,
+									   "commit_level");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -258,7 +283,8 @@ as_status set_remove_policy(as_policy_remove* remove_policy, PyObject* py_policy
 		return status;
 	}
 
-	status = set_optional_bool_property(&remove_policy->durable_delete, py_policy, "durable_delete");
+	status = set_optional_bool_property(&remove_policy->durable_delete,
+										py_policy, "durable_delete");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -266,7 +292,8 @@ as_status set_remove_policy(as_policy_remove* remove_policy, PyObject* py_policy
 	return AEROSPIKE_OK;
 }
 
-as_status set_query_policy(as_policy_query* query_policy, PyObject* py_policy) {
+as_status set_query_policy(as_policy_query *query_policy, PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 
@@ -283,7 +310,8 @@ as_status set_query_policy(as_policy_query* query_policy, PyObject* py_policy) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&query_policy->deserialize, py_policy, "deserialize");
+	status = set_optional_bool_property(&query_policy->deserialize, py_policy,
+										"deserialize");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -291,7 +319,8 @@ as_status set_query_policy(as_policy_query* query_policy, PyObject* py_policy) {
 	return AEROSPIKE_OK;
 }
 
-as_status set_scan_policy(as_policy_scan* scan_policy, PyObject* py_policy) {
+as_status set_scan_policy(as_policy_scan *scan_policy, PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 
@@ -307,12 +336,8 @@ as_status set_scan_policy(as_policy_scan* scan_policy, PyObject* py_policy) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&scan_policy->durable_delete, py_policy, "durable_delete");
-	if (status != AEROSPIKE_OK) {
-		return status;
-	}
-
-	status = set_optional_bool_property(&scan_policy->fail_on_cluster_change, py_policy, "fail_on_cluster_change");
+	status = set_optional_bool_property(&scan_policy->durable_delete, py_policy,
+										"durable_delete");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -320,7 +345,9 @@ as_status set_scan_policy(as_policy_scan* scan_policy, PyObject* py_policy) {
 	return AEROSPIKE_OK;
 }
 
-as_status set_operate_policy(as_policy_operate* operate_policy, PyObject* py_policy) {
+as_status set_operate_policy(as_policy_operate *operate_policy,
+							 PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 
@@ -342,12 +369,14 @@ as_status set_operate_policy(as_policy_operate* operate_policy, PyObject* py_pol
 		return status;
 	}
 
-	status = set_optional_replica(&operate_policy->replica, py_policy, "replica");
+	status =
+		set_optional_replica(&operate_policy->replica, py_policy, "replica");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_commit_level(&operate_policy->commit_level, py_policy, "commit_level");
+	status = set_optional_commit_level(&operate_policy->commit_level, py_policy,
+									   "commit_level");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -357,25 +386,28 @@ as_status set_operate_policy(as_policy_operate* operate_policy, PyObject* py_pol
 		return status;
 	}
 
-	status = set_optional_bool_property(&operate_policy->durable_delete, py_policy, "durable_delete");
+	status = set_optional_bool_property(&operate_policy->durable_delete,
+										py_policy, "durable_delete");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&operate_policy->deserialize, py_policy, "deserialize");
+	status = set_optional_bool_property(&operate_policy->deserialize, py_policy,
+										"deserialize");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
+	// 4.0.0 onwards
 
-    // 4.0.0 onwards
-
-	status = set_optional_ap_read_mode(&operate_policy->read_mode_ap, py_policy, "read_mode_ap");
+	status = set_optional_ap_read_mode(&operate_policy->read_mode_ap, py_policy,
+									   "read_mode_ap");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_sc_read_mode(&operate_policy->read_mode_sc, py_policy, "read_mode_sc");
+	status = set_optional_sc_read_mode(&operate_policy->read_mode_sc, py_policy,
+									   "read_mode_sc");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -383,7 +415,8 @@ as_status set_operate_policy(as_policy_operate* operate_policy, PyObject* py_pol
 	return AEROSPIKE_OK;
 }
 
-as_status set_batch_policy(as_policy_batch* batch_policy, PyObject* py_policy) {
+as_status set_batch_policy(as_policy_batch *batch_policy, PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 	if (!py_policy) {
@@ -399,33 +432,32 @@ as_status set_batch_policy(as_policy_batch* batch_policy, PyObject* py_policy) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&batch_policy->concurrent, py_policy, "concurrent");
+	status = set_optional_bool_property(&batch_policy->concurrent, py_policy,
+										"concurrent");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&batch_policy->allow_inline, py_policy, "allow_inline");
+	status = set_optional_bool_property(&batch_policy->allow_inline, py_policy,
+										"allow_inline");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&batch_policy->send_set_name, py_policy, "send_set_name");
+	status = set_optional_bool_property(&batch_policy->deserialize, py_policy,
+										"deserialize");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_bool_property(&batch_policy->deserialize, py_policy, "deserialize");
+	status = set_optional_ap_read_mode(&batch_policy->read_mode_ap, py_policy,
+									   "read_mode_ap");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-
-	status = set_optional_ap_read_mode(&batch_policy->read_mode_ap, py_policy, "read_mode_ap");
-	if (status != AEROSPIKE_OK) {
-		return status;
-	}
-
-	status = set_optional_sc_read_mode(&batch_policy->read_mode_sc, py_policy, "read_mode_sc");
+	status = set_optional_sc_read_mode(&batch_policy->read_mode_sc, py_policy,
+									   "read_mode_sc");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -433,7 +465,8 @@ as_status set_batch_policy(as_policy_batch* batch_policy, PyObject* py_policy) {
 	return AEROSPIKE_OK;
 }
 
-as_status set_base_policy(as_policy_base* base_policy, PyObject* py_policy) {
+as_status set_base_policy(as_policy_base *base_policy, PyObject *py_policy)
+{
 
 	as_status status = AEROSPIKE_OK;
 
@@ -445,22 +478,27 @@ as_status set_base_policy(as_policy_base* base_policy, PyObject* py_policy) {
 		return AEROSPIKE_ERR_PARAM;
 	}
 
-	status = set_optional_uint32_property((uint32_t*)&base_policy->total_timeout, py_policy, "total_timeout");
+	status = set_optional_uint32_property(
+		(uint32_t *)&base_policy->total_timeout, py_policy, "total_timeout");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_uint32_property((uint32_t*)&base_policy->socket_timeout, py_policy, "socket_timeout");
+	status = set_optional_uint32_property(
+		(uint32_t *)&base_policy->socket_timeout, py_policy, "socket_timeout");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_uint32_property((uint32_t*)&base_policy->max_retries, py_policy, "max_retries");
+	status = set_optional_uint32_property((uint32_t *)&base_policy->max_retries,
+										  py_policy, "max_retries");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
 
-	status = set_optional_uint32_property((uint32_t*)&base_policy->sleep_between_retries, py_policy, "sleep_between_retries");
+	status = set_optional_uint32_property(
+		(uint32_t *)&base_policy->sleep_between_retries, py_policy,
+		"sleep_between_retries");
 	if (status != AEROSPIKE_OK) {
 		return status;
 	}
@@ -468,7 +506,8 @@ as_status set_base_policy(as_policy_base* base_policy, PyObject* py_policy) {
 	return AEROSPIKE_OK;
 }
 
-as_status get_uint32_value(PyObject* py_policy_val, uint32_t* return_uint32) {
+as_status get_uint32_value(PyObject *py_policy_val, uint32_t *return_uint32)
+{
 	long long int uint32_max = 0xFFFFFFFF;
 
 	if (!py_policy_val) {
@@ -492,8 +531,10 @@ as_status get_uint32_value(PyObject* py_policy_val, uint32_t* return_uint32) {
 	return AEROSPIKE_ERR_PARAM;
 }
 
-as_status set_optional_uint32_property(uint32_t* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_uint32_property(uint32_t *target_ptr,
+									   PyObject *py_policy, const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	long long int uint32_max = 0xFFFFFFFF;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
@@ -512,7 +553,7 @@ as_status set_optional_uint32_property(uint32_t* target_ptr, PyObject* py_policy
 			PyErr_Clear();
 			return AEROSPIKE_ERR_PARAM;
 
-		/* If the number was less than zero, or would not fit in a uint32, error */
+			/* If the number was less than zero, or would not fit in a uint32, error */
 		}
 		if (int_value < 0 || int_value > uint32_max) {
 			return AEROSPIKE_ERR_PARAM;
@@ -524,8 +565,10 @@ as_status set_optional_uint32_property(uint32_t* target_ptr, PyObject* py_policy
 	return AEROSPIKE_ERR_PARAM;
 }
 
-as_status set_optional_bool_property(bool* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_bool_property(bool *target_ptr, PyObject *py_policy,
+									 const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
 	}
@@ -541,8 +584,10 @@ as_status set_optional_bool_property(bool* target_ptr, PyObject* py_policy, cons
 	return AEROSPIKE_ERR_PARAM;
 }
 
-as_status set_optional_key(as_policy_key* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_key(as_policy_key *target_ptr, PyObject *py_policy,
+						   const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
 	}
@@ -561,8 +606,10 @@ as_status set_optional_key(as_policy_key* target_ptr, PyObject* py_policy, const
 	return AEROSPIKE_OK;
 }
 
-as_status set_optional_replica(as_policy_replica* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_replica(as_policy_replica *target_ptr,
+							   PyObject *py_policy, const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
 	}
@@ -581,8 +628,10 @@ as_status set_optional_replica(as_policy_replica* target_ptr, PyObject* py_polic
 	return AEROSPIKE_OK;
 }
 
-as_status set_optional_commit_level(as_policy_commit_level* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_commit_level(as_policy_commit_level *target_ptr,
+									PyObject *py_policy, const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
 	}
@@ -601,9 +650,10 @@ as_status set_optional_commit_level(as_policy_commit_level* target_ptr, PyObject
 	return AEROSPIKE_OK;
 }
 
-
-as_status set_optional_ap_read_mode(as_policy_read_mode_ap* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_ap_read_mode(as_policy_read_mode_ap *target_ptr,
+									PyObject *py_policy, const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
 	}
@@ -622,8 +672,10 @@ as_status set_optional_ap_read_mode(as_policy_read_mode_ap* target_ptr, PyObject
 	return AEROSPIKE_OK;
 }
 
-as_status set_optional_sc_read_mode(as_policy_read_mode_sc* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_sc_read_mode(as_policy_read_mode_sc *target_ptr,
+									PyObject *py_policy, const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
 	}
@@ -642,8 +694,10 @@ as_status set_optional_sc_read_mode(as_policy_read_mode_sc* target_ptr, PyObject
 	return AEROSPIKE_OK;
 }
 
-as_status set_optional_gen(as_policy_gen* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_gen(as_policy_gen *target_ptr, PyObject *py_policy,
+						   const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
 	}
@@ -662,8 +716,10 @@ as_status set_optional_gen(as_policy_gen* target_ptr, PyObject* py_policy, const
 	return AEROSPIKE_OK;
 }
 
-as_status set_optional_exists(as_policy_exists* target_ptr, PyObject* py_policy, const char* name) {
-	PyObject* py_policy_val = NULL;
+as_status set_optional_exists(as_policy_exists *target_ptr, PyObject *py_policy,
+							  const char *name)
+{
+	PyObject *py_policy_val = NULL;
 	if (!py_policy || !PyDict_Check(py_policy)) {
 		return AEROSPIKE_OK;
 	}
