@@ -28,14 +28,15 @@
 #include "policy.h"
 #include "operate.h"
 
-AerospikeQuery* AerospikeQuery_Add_Ops(AerospikeQuery * self, PyObject * args, PyObject * kwds)
+AerospikeQuery *AerospikeQuery_Add_Ops(AerospikeQuery *self, PyObject *args,
+									   PyObject *kwds)
 {
 	// Python function arguments.
-	PyObject* py_ops = NULL;
+	PyObject *py_ops = NULL;
 	// Python function keyword arguments.
-	static char* kwlist[] = {"ops", NULL};
+	static char *kwlist[] = {"ops", NULL};
 
-	if (! PyArg_ParseTupleAndKeywords(args, kwds, "O:ops", kwlist, &py_ops)) {
+	if (!PyArg_ParseTupleAndKeywords(args, kwds, "O:ops", kwlist, &py_ops)) {
 		return NULL;
 	}
 
@@ -53,13 +54,14 @@ AerospikeQuery* AerospikeQuery_Add_Ops(AerospikeQuery * self, PyObject * args, P
 	as_error err;
 	as_error_init(&err);
 
-	if (! self || !self->client->as) {
+	if (!self || !self->client->as) {
 		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Invalid query object.");
 		goto CLEANUP;
 	}
 
-	if (! self->client->is_conn_16) {
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster.");
+	if (!self->client->is_conn_16) {
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,
+						"No connection to aerospike cluster.");
 		goto CLEANUP;
 	}
 
@@ -67,20 +69,26 @@ AerospikeQuery* AerospikeQuery_Add_Ops(AerospikeQuery * self, PyObject * args, P
 		Py_ssize_t size = PyList_Size(py_ops);
 		self->query.ops = as_operations_new((uint16_t)size);
 		if (self->query.ops == NULL) {
-			as_error_update(&err, AEROSPIKE_ERR_PARAM, "Failed to create new as_operations.");
+			as_error_update(&err, AEROSPIKE_ERR_PARAM,
+							"Failed to create new as_operations.");
 			goto CLEANUP;
 		}
 
 		for (int i = 0; i < size; i++) {
-			PyObject * py_val = PyList_GetItem(py_ops, (Py_ssize_t)i);
+			PyObject *py_val = PyList_GetItem(py_ops, (Py_ssize_t)i);
 			if (PyDict_Check(py_val)) {
-				if (add_op(self->client, &err, py_val, self->unicodeStrVector, self->static_pool, self->query.ops, &operation, &return_type) != AEROSPIKE_OK) { //something wrong with ops bin name and value
-					as_error_update(&err, AEROSPIKE_ERR_PARAM, "Failed to convert ops.");
+				if (add_op(self->client, &err, py_val, self->unicodeStrVector,
+						   self->static_pool, self->query.ops, &operation,
+						   &return_type) !=
+					AEROSPIKE_OK) { //something wrong with ops bin name and value
+					as_error_update(&err, AEROSPIKE_ERR_PARAM,
+									"Failed to convert ops.");
 					goto CLEANUP;
 				}
 			}
 			else {
-				as_error_update(&err, AEROSPIKE_ERR_PARAM, "Failed to convert ops.");
+				as_error_update(&err, AEROSPIKE_ERR_PARAM,
+								"Failed to convert ops.");
 				goto CLEANUP;
 			}
 		}
@@ -92,8 +100,8 @@ AerospikeQuery* AerospikeQuery_Add_Ops(AerospikeQuery * self, PyObject * args, P
 
 CLEANUP:
 
-	if ( err.code != AEROSPIKE_OK ) {
-		PyObject * py_err = NULL;
+	if (err.code != AEROSPIKE_OK) {
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		PyErr_SetObject(exception_type, py_err);
