@@ -28,21 +28,22 @@
 #include "policy.h"
 #include "operate.h"
 
-AerospikeScan* AerospikeScan_Add_Ops(AerospikeScan * self, PyObject * args, PyObject * kwds)
+AerospikeScan *AerospikeScan_Add_Ops(AerospikeScan *self, PyObject *args,
+									 PyObject *kwds)
 {
 	// Python function arguments.
-    PyObject* py_ops = NULL;
+	PyObject *py_ops = NULL;
 	// Python function keyword arguments.
-    static char* kwlist[] = {"ops", NULL};
+	static char *kwlist[] = {"ops", NULL};
 
-	if (! PyArg_ParseTupleAndKeywords(args, kwds, "O:ops", kwlist, &py_ops)) {
+	if (!PyArg_ParseTupleAndKeywords(args, kwds, "O:ops", kwlist, &py_ops)) {
 		return NULL;
 	}
 
 	// Aerospike API arguments.
-    long return_type = -1;
-    long operation;
-    self->unicodeStrVector = as_vector_create(sizeof(char *), 128);
+	long return_type = -1;
+	long operation;
+	self->unicodeStrVector = as_vector_create(sizeof(char *), 128);
 
 	as_static_pool static_pool;
 	memset(&static_pool, 0, sizeof(static_pool));
@@ -51,44 +52,49 @@ AerospikeScan* AerospikeScan_Add_Ops(AerospikeScan * self, PyObject * args, PyOb
 	as_error err;
 	as_error_init(&err);
 
-	if (! self || !self->client->as) {
+	if (!self || !self->client->as) {
 		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Invalid scan object.");
 		goto CLEANUP;
 	}
 
-	if (! self->client->is_conn_16) {
-		as_error_update(&err, AEROSPIKE_ERR_CLUSTER, "No connection to aerospike cluster.");
+	if (!self->client->is_conn_16) {
+		as_error_update(&err, AEROSPIKE_ERR_CLUSTER,
+						"No connection to aerospike cluster.");
 		goto CLEANUP;
 	}
 
-    if (PyList_Check(py_ops)) {
-        Py_ssize_t size = PyList_Size(py_ops);
-        self->scan.ops = as_operations_new((uint16_t)size);
+	if (PyList_Check(py_ops)) {
+		Py_ssize_t size = PyList_Size(py_ops);
+		self->scan.ops = as_operations_new((uint16_t)size);
 
-        for (int i = 0; i < size; i++) {
-            PyObject * py_val = PyList_GetItem(py_ops, (Py_ssize_t)i);
-            
-            if (PyDict_Check(py_val)) {
-                if (add_op(self->client, &err, py_val, self->unicodeStrVector, self->static_pool, self->scan.ops, &operation, &return_type) != AEROSPIKE_OK) {
-                    as_error_update(&err, AEROSPIKE_ERR_PARAM, "Failed to convert ops.");
-                    goto CLEANUP;
-                }
-            }
-            else {
-                as_error_update(&err, AEROSPIKE_ERR_PARAM, "Failed to convert ops.");
-                goto CLEANUP;
-            }
-        }
-    }
-    else {
-        as_error_update(&err, AEROSPIKE_ERR_CLIENT, "Ops must be list.");
+		for (int i = 0; i < size; i++) {
+			PyObject *py_val = PyList_GetItem(py_ops, (Py_ssize_t)i);
+
+			if (PyDict_Check(py_val)) {
+				if (add_op(self->client, &err, py_val, self->unicodeStrVector,
+						   self->static_pool, self->scan.ops, &operation,
+						   &return_type) != AEROSPIKE_OK) {
+					as_error_update(&err, AEROSPIKE_ERR_PARAM,
+									"Failed to convert ops.");
+					goto CLEANUP;
+				}
+			}
+			else {
+				as_error_update(&err, AEROSPIKE_ERR_PARAM,
+								"Failed to convert ops.");
+				goto CLEANUP;
+			}
+		}
+	}
+	else {
+		as_error_update(&err, AEROSPIKE_ERR_CLIENT, "Ops must be list.");
 		goto CLEANUP;
-    }
+	}
 
 CLEANUP:
 
-	if ( err.code != AEROSPIKE_OK ) {
-		PyObject * py_err = NULL;
+	if (err.code != AEROSPIKE_OK) {
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		PyErr_SetObject(exception_type, py_err);
