@@ -44,32 +44,35 @@ user_serializer_callback user_serializer_call_info, user_deserializer_call_info;
  * Returns  integer handle for the serializer being set.
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_Set_Serializer(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_Set_Serializer(AerospikeClient *self, PyObject *args,
+										 PyObject *kwds)
 {
 	// Python Function Arguments
-	PyObject * py_func = NULL;
+	PyObject *py_func = NULL;
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"function", NULL};
+	static char *kwlist[] = {"function", NULL};
 	as_error err;
 	// Initialize error
 	as_error_init(&err);
 
 	// Python Function Argument Parsing
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "O:set_serializer", kwlist,
-				&py_func) == false) {
+									&py_func) == false) {
 		return NULL;
 	}
 
 	if (!is_user_serializer_registered) {
-		memset(&user_serializer_call_info, 0, sizeof(user_serializer_call_info));
+		memset(&user_serializer_call_info, 0,
+			   sizeof(user_serializer_call_info));
 	}
 
 	if (user_serializer_call_info.callback == py_func) {
 		return PyLong_FromLong(0);
 	}
 	if (!PyCallable_Check(py_func)) {
-		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Parameter must be a callable");
+		as_error_update(&err, AEROSPIKE_ERR_PARAM,
+						"Parameter must be a callable");
 		goto CLEANUP;
 	}
 
@@ -82,7 +85,7 @@ PyObject * AerospikeClient_Set_Serializer(AerospikeClient * self, PyObject * arg
 
 CLEANUP:
 	if (err.code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		PyErr_SetObject(exception_type, py_err);
@@ -105,24 +108,26 @@ CLEANUP:
  * Returns  integer handle for the deserializer being set
  *******************************************************************************************************
  */
-PyObject * AerospikeClient_Set_Deserializer(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_Set_Deserializer(AerospikeClient *self,
+										   PyObject *args, PyObject *kwds)
 {
 	// Python Function Arguments
-	PyObject * py_func = NULL;
+	PyObject *py_func = NULL;
 
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {"function", NULL};
+	static char *kwlist[] = {"function", NULL};
 	as_error err;
 	as_error_init(&err);
 
 	// Python Function Argument Parsing
 	if (PyArg_ParseTupleAndKeywords(args, kwds, "O:set_deserializer", kwlist,
-				&py_func) == false) {
+									&py_func) == false) {
 		return NULL;
 	}
 
 	if (!is_user_deserializer_registered) {
-		memset(&user_deserializer_call_info, 0, sizeof(user_deserializer_call_info));
+		memset(&user_deserializer_call_info, 0,
+			   sizeof(user_deserializer_call_info));
 	}
 
 	if (user_deserializer_call_info.callback == py_func) {
@@ -130,7 +135,8 @@ PyObject * AerospikeClient_Set_Deserializer(AerospikeClient * self, PyObject * a
 	}
 
 	if (!PyCallable_Check(py_func)) {
-		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Parameter must be a callable");
+		as_error_update(&err, AEROSPIKE_ERR_PARAM,
+						"Parameter must be a callable");
 		goto CLEANUP;
 	}
 	is_user_deserializer_registered = 1;
@@ -142,7 +148,7 @@ PyObject * AerospikeClient_Set_Deserializer(AerospikeClient * self, PyObject * a
 
 CLEANUP:
 	if (err.code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyObject *exception_type = raise_exception(&err);
 		PyErr_SetObject(exception_type, py_err);
@@ -166,11 +172,9 @@ CLEANUP:
  * @param error_p               The error object
  ******************************************************************************************************
  */
-void set_as_bytes(as_bytes **bytes,
-		uint8_t *bytes_string,
-		int32_t bytes_string_len,
-		int32_t bytes_type,
-		as_error *error_p)
+void set_as_bytes(as_bytes **bytes, uint8_t *bytes_string,
+				  int32_t bytes_string_len, int32_t bytes_type,
+				  as_error *error_p)
 {
 	if ((!bytes) || (!bytes_string)) {
 		as_error_update(error_p, AEROSPIKE_ERR, "Unable to set as_bytes");
@@ -181,14 +185,15 @@ void set_as_bytes(as_bytes **bytes,
 
 	if (!as_bytes_set(*bytes, 0, bytes_string, bytes_string_len)) {
 		as_error_update(error_p, AEROSPIKE_ERR, "Unable to set as_bytes");
-	} else {
+	}
+	else {
 		as_bytes_set_type(*bytes, bytes_type);
 	}
 
 CLEANUP:
 
-  if (error_p->code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+	if (error_p->code != AEROSPIKE_OK) {
+		PyObject *py_err = NULL;
 		error_to_pyobject(error_p, &py_err);
 		PyObject *exception_type = raise_exception(error_p);
 		PyErr_SetObject(exception_type, py_err);
@@ -216,34 +221,34 @@ CLEANUP:
  *******************************************************************************************************
  */
 void execute_user_callback(user_serializer_callback *user_callback_info,
-		as_bytes **bytes,
-		PyObject **value,
-		bool serialize_flag,
-		as_error *error_p)
+						   as_bytes **bytes, PyObject **value,
+						   bool serialize_flag, as_error *error_p)
 {
-	PyObject * py_return = NULL;
-	PyObject * py_value = NULL;
-	PyObject * py_arglist = PyTuple_New(1);
+	PyObject *py_return = NULL;
+	PyObject *py_value = NULL;
+	PyObject *py_arglist = PyTuple_New(1);
 
 	if (serialize_flag) {
 		Py_XINCREF(*value);
-		if (PyTuple_SetItem(py_arglist, 0 , *value) != 0) {
+		if (PyTuple_SetItem(py_arglist, 0, *value) != 0) {
 			Py_DECREF(py_arglist);
 			goto CLEANUP;
 		}
-	} else {
-		as_bytes * bytes_pointer = *bytes;
-		char*       bytes_val_p = (char*)bytes_pointer->value;
-		py_value = PyString_FromStringAndSize(bytes_val_p, as_bytes_size(*bytes));
-		if (PyTuple_SetItem(py_arglist, 0 , py_value) != 0){
+	}
+	else {
+		as_bytes *bytes_pointer = *bytes;
+		char *bytes_val_p = (char *)bytes_pointer->value;
+		py_value =
+			PyString_FromStringAndSize(bytes_val_p, as_bytes_size(*bytes));
+		if (PyTuple_SetItem(py_arglist, 0, py_value) != 0) {
 			Py_DECREF(py_arglist);
 			goto CLEANUP;
 		}
 	}
 
-	Py_INCREF(user_callback_info -> callback);
-	py_return = PyEval_CallObject(user_callback_info->callback, py_arglist);
-	Py_DECREF(user_callback_info -> callback);
+	Py_INCREF(user_callback_info->callback);
+	py_return = PyObject_Call(user_callback_info->callback, py_arglist, NULL);
+	Py_DECREF(user_callback_info->callback);
 	Py_DECREF(py_arglist);
 
 	if (py_return) {
@@ -251,32 +256,36 @@ void execute_user_callback(user_serializer_callback *user_callback_info,
 			char *py_val;
 			Py_ssize_t len;
 #if PY_MAJOR_VERSION >= 3
-			py_val = (char*)PyUnicode_AsUTF8AndSize(py_return, &len);
+			py_val = (char *)PyUnicode_AsUTF8AndSize(py_return, &len);
 #else
 			py_val = PyString_AsString(py_return);
 			len = PyString_Size(py_return);
 #endif
-			set_as_bytes(bytes, (uint8_t *) py_val,
-					len, AS_BYTES_BLOB, error_p);
+			set_as_bytes(bytes, (uint8_t *)py_val, len, AS_BYTES_BLOB, error_p);
 			Py_DECREF(py_return);
-		} else {
+		}
+		else {
 			*value = py_return;
 		}
-	} else {
+	}
+	else {
 		if (serialize_flag) {
-			as_error_update(error_p, AEROSPIKE_ERR,
-					"Unable to call user's registered serializer callback");
+			as_error_update(
+				error_p, AEROSPIKE_ERR,
+				"Unable to call user's registered serializer callback");
 			goto CLEANUP;
-		} else {
-			as_error_update(error_p, AEROSPIKE_ERR,
-					"Unable to call user's registered deserializer callback");
+		}
+		else {
+			as_error_update(
+				error_p, AEROSPIKE_ERR,
+				"Unable to call user's registered deserializer callback");
 			goto CLEANUP;
 		}
 	}
 
 CLEANUP:
-  if (error_p->code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+	if (error_p->code != AEROSPIKE_OK) {
+		PyObject *py_err = NULL;
 		error_to_pyobject(error_p, &py_err);
 		PyObject *exception_type = raise_exception(error_p);
 		PyErr_SetObject(exception_type, py_err);
@@ -298,14 +307,14 @@ CLEANUP:
  *                                  with encountered error if any.
  *******************************************************************************************************
  */
-extern as_status serialize_based_on_serializer_policy(AerospikeClient * self,
-		int32_t serializer_policy,
-		as_bytes **bytes,
-		PyObject *value,
-		as_error *error_p)
+extern as_status serialize_based_on_serializer_policy(AerospikeClient *self,
+													  int32_t serializer_policy,
+													  as_bytes **bytes,
+													  PyObject *value,
+													  as_error *error_p)
 {
 	uint8_t use_client_serializer = true;
-	PyObject* initresult = NULL;
+	PyObject *initresult = NULL;
 
 	if (self->is_client_put_serializer) {
 		if (serializer_policy == SERIALIZER_USER) {
@@ -313,120 +322,132 @@ extern as_status serialize_based_on_serializer_policy(AerospikeClient * self,
 				use_client_serializer = false;
 			}
 		}
-	} else if (self->user_serializer_call_info.callback) {
+	}
+	else if (self->user_serializer_call_info.callback) {
 		serializer_policy = SERIALIZER_USER;
 	}
 
-	switch(serializer_policy) {
-		case SERIALIZER_NONE:
-			as_error_update(error_p, AEROSPIKE_ERR_PARAM,
-					"Cannot serialize: SERIALIZER_NONE selected");
-			goto CLEANUP;
-		case SERIALIZER_PYTHON:
-			{
-				/*
+	switch (serializer_policy) {
+	case SERIALIZER_NONE:
+		as_error_update(error_p, AEROSPIKE_ERR_PARAM,
+						"Cannot serialize: SERIALIZER_NONE selected");
+		goto CLEANUP;
+	case SERIALIZER_PYTHON: {
+		/*
 				 * Serialize bytearray as is and store them into database with
 				 * type AS_BYTES_BLOB, unlike other values in case of 
 				 * SERIALIZER_PYTHON.
 				 * This is a special case.
 				 * Refer: AER-3589 for more details.
 				 */
-				if (PyByteArray_Check(value)) {
-					uint8_t *bytes_array = (uint8_t *) PyByteArray_AsString(value);
-					uint32_t bytes_array_len  = (uint32_t)  PyByteArray_Size(value);
-					set_as_bytes(bytes, bytes_array, bytes_array_len, AS_BYTES_BLOB, error_p);
-				} else if (PyBytes_Check(value)) {
-					uint8_t *my_bytes = (uint8_t *) PyBytes_AsString(value);
-					uint32_t my_bytes_len  = (uint32_t)  PyBytes_Size(value);
-					set_as_bytes(bytes, my_bytes, my_bytes_len, AS_BYTES_BLOB, error_p);
-				} else {
+		if (PyByteArray_Check(value)) {
+			uint8_t *bytes_array = (uint8_t *)PyByteArray_AsString(value);
+			uint32_t bytes_array_len = (uint32_t)PyByteArray_Size(value);
+			set_as_bytes(bytes, bytes_array, bytes_array_len, AS_BYTES_BLOB,
+						 error_p);
+		}
+		else if (PyBytes_Check(value)) {
+			uint8_t *my_bytes = (uint8_t *)PyBytes_AsString(value);
+			uint32_t my_bytes_len = (uint32_t)PyBytes_Size(value);
+			set_as_bytes(bytes, my_bytes, my_bytes_len, AS_BYTES_BLOB, error_p);
+		}
+		else {
 
-					/* get the sys.modules dictionary */
-					PyObject* sysmodules = PyImport_GetModuleDict();
-					PyObject* cpickle_module = NULL;
-					if (PyMapping_HasKeyString(sysmodules, "pickle")) {
-						cpickle_module = PyMapping_GetItemString(sysmodules, "pickle");
-					} else {
-						cpickle_module = PyImport_ImportModule("pickle");
-					}
+			/* get the sys.modules dictionary */
+			PyObject *sysmodules = PyImport_GetModuleDict();
+			PyObject *cpickle_module = NULL;
+			if (PyMapping_HasKeyString(sysmodules, "pickle")) {
+				cpickle_module = PyMapping_GetItemString(sysmodules, "pickle");
+			}
+			else {
+				cpickle_module = PyImport_ImportModule("pickle");
+			}
 
-					if (!cpickle_module) {
-						/* insert error handling here! and exit this function */
-						as_error_update(error_p, AEROSPIKE_ERR_CLIENT, "Unable to load pickle module");
-						goto CLEANUP;
-					} else {
-						PyObject * py_funcname = PyString_FromString("dumps");
+			if (!cpickle_module) {
+				/* insert error handling here! and exit this function */
+				as_error_update(error_p, AEROSPIKE_ERR_CLIENT,
+								"Unable to load pickle module");
+				goto CLEANUP;
+			}
+			else {
+				PyObject *py_funcname = PyString_FromString("dumps");
 
-						Py_INCREF(cpickle_module);
-						initresult = PyObject_CallMethodObjArgs(cpickle_module,
-								py_funcname, value, NULL);
-						Py_DECREF(cpickle_module);
-						Py_DECREF(py_funcname);
+				Py_INCREF(cpickle_module);
+				initresult = PyObject_CallMethodObjArgs(
+					cpickle_module, py_funcname, value, NULL);
+				Py_DECREF(cpickle_module);
+				Py_DECREF(py_funcname);
 
-						if (!initresult) {
-							/* more error handling &c */
-							as_error_update(error_p, AEROSPIKE_ERR_CLIENT, "Unable to call dumps function");
-							goto CLEANUP;
-						} else {
-							Py_INCREF(initresult);
+				if (!initresult) {
+					/* more error handling &c */
+					as_error_update(error_p, AEROSPIKE_ERR_CLIENT,
+									"Unable to call dumps function");
+					goto CLEANUP;
+				}
+				else {
+					Py_INCREF(initresult);
 
-							char *return_value;
-							Py_ssize_t len;
-							PyBytes_AsStringAndSize(initresult, &return_value, &len);
-							set_as_bytes(bytes, (uint8_t *) return_value,
-									len, AS_BYTES_PYTHON, error_p);
-							Py_DECREF(initresult);
-						}
-					}
-					Py_XDECREF(cpickle_module);
+					char *return_value;
+					Py_ssize_t len;
+					PyBytes_AsStringAndSize(initresult, &return_value, &len);
+					set_as_bytes(bytes, (uint8_t *)return_value, len,
+								 AS_BYTES_PYTHON, error_p);
+					Py_DECREF(initresult);
 				}
 			}
-			break;
-		case SERIALIZER_JSON:
-			/*
+			Py_XDECREF(cpickle_module);
+		}
+	} break;
+	case SERIALIZER_JSON:
+		/*
 			 *   TODO:
 			 *     Handle JSON serialization after support for AS_BYTES_JSON
 			 *     is added in aerospike-client-c
 			 */
-			as_error_update(error_p, AEROSPIKE_ERR,
-					"Unable to serialize using standard json serializer");
-			goto CLEANUP;
+		as_error_update(error_p, AEROSPIKE_ERR,
+						"Unable to serialize using standard json serializer");
+		goto CLEANUP;
 
-		case SERIALIZER_USER:
-			if (use_client_serializer) {
-				execute_user_callback(&self->user_serializer_call_info, bytes, &value, true, error_p);
+	case SERIALIZER_USER:
+		if (use_client_serializer) {
+			execute_user_callback(&self->user_serializer_call_info, bytes,
+								  &value, true, error_p);
+			if (AEROSPIKE_OK != (error_p->code)) {
+				goto CLEANUP;
+			}
+		}
+		else {
+			if (is_user_serializer_registered) {
+				execute_user_callback(&user_serializer_call_info, bytes, &value,
+									  true, error_p);
 				if (AEROSPIKE_OK != (error_p->code)) {
 					goto CLEANUP;
 				}
-			} else {
-				if (is_user_serializer_registered) {
-					execute_user_callback(&user_serializer_call_info, bytes, &value, true, error_p);
-					if (AEROSPIKE_OK != (error_p->code)) {
-						goto CLEANUP;
-					}
-				} else if (self->user_serializer_call_info.callback) {
-					execute_user_callback(&self->user_serializer_call_info, bytes, &value, true, error_p);
-					if (AEROSPIKE_OK != (error_p->code)) {
-						goto CLEANUP;
-					}
-				} else {
-					as_error_update(error_p, AEROSPIKE_ERR,
-						"No serializer callback registered");
+			}
+			else if (self->user_serializer_call_info.callback) {
+				execute_user_callback(&self->user_serializer_call_info, bytes,
+									  &value, true, error_p);
+				if (AEROSPIKE_OK != (error_p->code)) {
 					goto CLEANUP;
 				}
 			}
-			break;
-		default:
-			as_error_update(error_p, AEROSPIKE_ERR,
-					"Unsupported serializer");
-			goto CLEANUP;
+			else {
+				as_error_update(error_p, AEROSPIKE_ERR,
+								"No serializer callback registered");
+				goto CLEANUP;
+			}
+		}
+		break;
+	default:
+		as_error_update(error_p, AEROSPIKE_ERR, "Unsupported serializer");
+		goto CLEANUP;
 	}
 
 CLEANUP:
 
 	Py_XDECREF(initresult);
 	if (error_p->code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(error_p, &py_err);
 		PyObject *exception_type = raise_exception(error_p);
 		PyErr_SetObject(exception_type, py_err);
@@ -449,112 +470,130 @@ CLEANUP:
  *                              with encountered error if any.
  *******************************************************************************************************
  */
-extern as_status deserialize_based_on_as_bytes_type(AerospikeClient * self,
-		as_bytes  *bytes,
-		PyObject  **retval,
-		as_error  *error_p)
+extern as_status deserialize_based_on_as_bytes_type(AerospikeClient *self,
+													as_bytes *bytes,
+													PyObject **retval,
+													as_error *error_p)
 {
-	switch(as_bytes_get_type(bytes)) {
-		case AS_BYTES_PYTHON: {
-								PyObject* sysmodules = PyImport_GetModuleDict();
-								PyObject* cpickle_module = NULL;
-								if (PyMapping_HasKeyString(sysmodules, "pickle")) {
-									cpickle_module = PyMapping_GetItemString(sysmodules, "pickle");
-								} else {
-									cpickle_module = PyImport_ImportModule("pickle");
-								}
+	switch (as_bytes_get_type(bytes)) {
+	case AS_BYTES_PYTHON: {
+		PyObject *sysmodules = PyImport_GetModuleDict();
+		PyObject *cpickle_module = NULL;
+		if (PyMapping_HasKeyString(sysmodules, "pickle")) {
+			cpickle_module = PyMapping_GetItemString(sysmodules, "pickle");
+		}
+		else {
+			cpickle_module = PyImport_ImportModule("pickle");
+		}
 
-								PyObject* initresult = NULL;
-								if (!cpickle_module) {
-									/* insert error handling here! and exit this function */
-									as_error_update(error_p, AEROSPIKE_ERR_CLIENT, "Unable to load pickle module");
-									goto CLEANUP;
-								} else {
-									char*       bytes_val_p = (char*)bytes->value;
-									PyObject *py_value = PyBytes_FromStringAndSize(bytes_val_p, as_bytes_size(bytes));
-									PyObject *py_funcname = PyString_FromString("loads");
+		PyObject *initresult = NULL;
+		if (!cpickle_module) {
+			/* insert error handling here! and exit this function */
+			as_error_update(error_p, AEROSPIKE_ERR_CLIENT,
+							"Unable to load pickle module");
+			goto CLEANUP;
+		}
+		else {
+			char *bytes_val_p = (char *)bytes->value;
+			PyObject *py_value =
+				PyBytes_FromStringAndSize(bytes_val_p, as_bytes_size(bytes));
+			PyObject *py_funcname = PyString_FromString("loads");
 
-									Py_INCREF(cpickle_module);
-									initresult = PyObject_CallMethodObjArgs(cpickle_module, py_funcname, py_value, NULL);
-									Py_DECREF(cpickle_module);
-									Py_DECREF(py_funcname);
-									Py_DECREF(py_value);
-									if (!initresult) {
-										// At this point we want to try to fallback to returning a byte array
-										uint32_t bval_size = as_bytes_size(bytes);
-										initresult = PyByteArray_FromStringAndSize((char *) as_bytes_get(bytes), bval_size);
-										// We couldn't convert the value into a byte array
-										if (!initresult) {
-											as_error_update(error_p, AEROSPIKE_ERR_CLIENT, "Unable to deserialize bytes");
-											Py_XDECREF(cpickle_module);
-											goto CLEANUP;
-										}
-										// The fallback deserialization succeeded
-										*retval = initresult;
-										as_error_update(error_p, AEROSPIKE_OK, NULL);
-									} else {
-										*retval = initresult;
-									}
-								}
-								Py_XDECREF(cpickle_module);
-							}
-							break;
-		case AS_BYTES_BLOB: {
-								if (self->user_deserializer_call_info.callback) {
-									execute_user_callback(&self->user_deserializer_call_info, &bytes, retval, false, error_p);
-									if (AEROSPIKE_OK != (error_p->code)) {
-										uint32_t bval_size = as_bytes_size(bytes);
-										PyObject *py_val = PyByteArray_FromStringAndSize((char *) as_bytes_get(bytes), bval_size);
-										if (!py_val) {
-											as_error_update(error_p, AEROSPIKE_ERR_CLIENT, "Unable to deserialize bytes");
-											goto CLEANUP;
-										}
-										*retval = py_val;
-										as_error_update(error_p, AEROSPIKE_OK, NULL);
-									}
-								} else {
-									if (is_user_deserializer_registered) {
-										execute_user_callback(&user_deserializer_call_info, &bytes, retval, false, error_p);
-										if (AEROSPIKE_OK != (error_p->code)) {
-											uint32_t bval_size = as_bytes_size(bytes);
-											PyObject *py_val = PyByteArray_FromStringAndSize((char *) as_bytes_get(bytes), bval_size);
-											if (!py_val) {
-												as_error_update(error_p, AEROSPIKE_ERR_CLIENT, "Unable to deserialize bytes");
-												goto CLEANUP;
-											}
-											as_error_update(error_p, AEROSPIKE_OK, NULL);
-											*retval = py_val;
-										}
-									} else {
-										uint32_t bval_size = as_bytes_size(bytes);
-										PyObject *py_val = PyByteArray_FromStringAndSize((char *) as_bytes_get(bytes), bval_size);
-										if (!py_val) {
-											as_error_update(error_p, AEROSPIKE_ERR_CLIENT, "Unable to deserialize bytes");
-											goto CLEANUP;
-										}
-										*retval = py_val;
-									}
-								}
-							}
-							break;
-		default:			{
-								// First try to return a raw byte array, if that fails raise an error
-								uint32_t bval_size = as_bytes_size(bytes);
-								PyObject* py_val = PyByteArray_FromStringAndSize((char*)as_bytes_get(bytes), bval_size);
-								if (py_val) {
-									*retval = py_val;
-								} else {
-									as_error_update(error_p, AEROSPIKE_ERR,
-											"Unable to deserialize bytes");
-									goto CLEANUP;
-								}
-							}
+			Py_INCREF(cpickle_module);
+			initresult = PyObject_CallMethodObjArgs(cpickle_module, py_funcname,
+													py_value, NULL);
+			Py_DECREF(cpickle_module);
+			Py_DECREF(py_funcname);
+			Py_DECREF(py_value);
+			if (!initresult) {
+				// At this point we want to try to fallback to returning a byte array
+				uint32_t bval_size = as_bytes_size(bytes);
+				initresult = PyByteArray_FromStringAndSize(
+					(char *)as_bytes_get(bytes), bval_size);
+				// We couldn't convert the value into a byte array
+				if (!initresult) {
+					as_error_update(error_p, AEROSPIKE_ERR_CLIENT,
+									"Unable to deserialize bytes");
+					Py_XDECREF(cpickle_module);
+					goto CLEANUP;
+				}
+				// The fallback deserialization succeeded
+				*retval = initresult;
+				as_error_update(error_p, AEROSPIKE_OK, NULL);
+			}
+			else {
+				*retval = initresult;
+			}
+		}
+		Py_XDECREF(cpickle_module);
+	} break;
+	case AS_BYTES_BLOB: {
+		if (self->user_deserializer_call_info.callback) {
+			execute_user_callback(&self->user_deserializer_call_info, &bytes,
+								  retval, false, error_p);
+			if (AEROSPIKE_OK != (error_p->code)) {
+				uint32_t bval_size = as_bytes_size(bytes);
+				PyObject *py_val = PyBytes_FromStringAndSize(
+					(char *)as_bytes_get(bytes), bval_size);
+				if (!py_val) {
+					as_error_update(error_p, AEROSPIKE_ERR_CLIENT,
+									"Unable to deserialize bytes");
+					goto CLEANUP;
+				}
+				*retval = py_val;
+				as_error_update(error_p, AEROSPIKE_OK, NULL);
+			}
+		}
+		else {
+			if (is_user_deserializer_registered) {
+				execute_user_callback(&user_deserializer_call_info, &bytes,
+									  retval, false, error_p);
+				if (AEROSPIKE_OK != (error_p->code)) {
+					uint32_t bval_size = as_bytes_size(bytes);
+					PyObject *py_val = PyBytes_FromStringAndSize(
+						(char *)as_bytes_get(bytes), bval_size);
+					if (!py_val) {
+						as_error_update(error_p, AEROSPIKE_ERR_CLIENT,
+										"Unable to deserialize bytes");
+						goto CLEANUP;
+					}
+					as_error_update(error_p, AEROSPIKE_OK, NULL);
+					*retval = py_val;
+				}
+			}
+			else {
+				uint32_t bval_size = as_bytes_size(bytes);
+				PyObject *py_val = PyBytes_FromStringAndSize(
+					(char *)as_bytes_get(bytes), bval_size);
+				if (!py_val) {
+					as_error_update(error_p, AEROSPIKE_ERR_CLIENT,
+									"Unable to deserialize bytes");
+					goto CLEANUP;
+				}
+				*retval = py_val;
+			}
+		}
+	} break;
+	default: {
+		// First try to return a raw byte array, if that fails raise an error
+		uint32_t bval_size = as_bytes_size(bytes);
+		PyObject *py_val =
+			PyBytes_FromStringAndSize((char *)as_bytes_get(bytes), bval_size);
+		if (py_val) {
+			*retval = py_val;
+		}
+		else {
+			as_error_update(error_p, AEROSPIKE_ERR,
+							"Unable to deserialize bytes");
+			goto CLEANUP;
+		}
+	}
 	}
 
 CLEANUP:
 
 	if (error_p->code != AEROSPIKE_OK) {
-		PyObject * py_err = NULL;
+		PyObject *py_err = NULL;
 		error_to_pyobject(error_p, &py_err);
 		PyObject *exception_type = raise_exception(error_p);
 		PyErr_SetObject(exception_type, py_err);
@@ -565,21 +604,24 @@ CLEANUP:
 	PyErr_Clear();
 	return error_p->code;
 }
-PyObject * AerospikeClient_Unset_Serializers(AerospikeClient * self, PyObject * args, PyObject * kwds)
+PyObject *AerospikeClient_Unset_Serializers(AerospikeClient *self,
+											PyObject *args, PyObject *kwds)
 {
 	// Python Function Keyword Arguments
-	static char * kwlist[] = {NULL};
+	static char *kwlist[] = {NULL};
 	as_error err;
 	// Initialize error
 	as_error_init(&err);
 
 	// Python Function Argument Parsing
-	if ( PyArg_ParseTupleAndKeywords(args, kwds, ":unset_serializers", kwlist) == false ) {
+	if (PyArg_ParseTupleAndKeywords(args, kwds, ":unset_serializers", kwlist) ==
+		false) {
 		return NULL;
 	}
 	is_user_serializer_registered = 0;
 	is_user_deserializer_registered = 0;
-	memset(&user_deserializer_call_info, 0, sizeof(user_deserializer_call_info));
+	memset(&user_deserializer_call_info, 0,
+		   sizeof(user_deserializer_call_info));
 	memset(&user_serializer_call_info, 0, sizeof(user_serializer_call_info));
 
 	return PyLong_FromLong(0);
